@@ -5,8 +5,8 @@
 #ifndef CMDLINE_PROGRESS_H
 #define CMDLINE_PROGRESS_H
 
-class download_manager;
+class download_signal_log;
 
-download_manager *gen_cmdline_download_progress();
+download_signal_log *gen_cmdline_download_progress();
 
 #endif // CMDLINE_PROGRESS_H
