@@ -20,9 +20,9 @@
 
 #include <generic/util/util.h>
 
-#include <vscreen/fragment.h>
-#include <vscreen/vscreen.h>
-#include <vscreen/transcode.h>
+#include <cwidget/fragment.h>
+#include <cwidget/generic/util/transcode.h>
+#include <cwidget/toplevel.h>
 
 #include <apt-pkg/algorithms.h>
 #include <apt-pkg/dpkgpm.h>
@@ -31,6 +31,7 @@
 #include <apt-pkg/strutl.h>
 
 using namespace std;
+namespace cw = cwidget;
 
 string StdinEOFException::errmsg() const
 {
@@ -88,7 +89,7 @@ static string reason_string_list(set<reason> &reasons)
 	}
 
       string dep_type = const_cast<pkgCache::DepIterator &>(why->dep).DepType();
-      s += transcode(transcode(dep_type).substr(0, 1));
+      s += cw::util::transcode(cw::util::transcode(dep_type).substr(0, 1));
       s+=": ";
       s+=why->pkg.Name();
     }
@@ -485,7 +486,7 @@ static bool cmdline_show_preview(bool as_upgrade, pkgset &to_install,
 	      ((*apt_cache_file)[pkg].iFlags & pkgDepCache::ReInstall))
 	++ReInstall;
 
-      pkg_action_state state=find_pkg_state(pkg);
+      pkg_action_state state=find_pkg_state(pkg, *apt_cache_file);
 
       switch(state)
 	{
@@ -644,84 +645,88 @@ static void cmdline_parse_why(string response)
       bool success;
       string root = arguments.back();
       arguments.pop_back();
-      std::auto_ptr<fragment> frag(do_why(arguments, root, false, false, success));
+      std::auto_ptr<cw::fragment> frag(do_why(arguments, root, false, false, success));
       update_screen_width();
       if(frag.get() != NULL)
-	std::cout << frag->layout(screen_width, screen_width, style());
+	std::cout << frag->layout(screen_width, screen_width, cwidget::style());
       _error->DumpErrors();
     }
 }
 
-static inline fragment *flowindentbox(int i1, int irest, fragment *f)
+static inline cw::fragment *flowindentbox(int i1, int irest, cw::fragment *f)
 {
   return indentbox(i1, irest, flowbox(f));
 }
 
 static void prompt_help(ostream &out)
 {
-  fragment *f=indentbox(2, 2,
-			fragf(_("y: %F"
-				"n: %F"
-				"i: %F"
-				"c: %F"
-				"d: %F"
-				"s: %F"
-				"v: %F"
-				"w: %F"
-				"e: %F"
-				"%n"
-				"%F"
-				"%n"
-				"%F"
-				"%F"
-				"%F"
-				"%F"
-				"%F"
-				"%F"
-				"%F"
-				"%F"
-				"%F"),
-			      flowindentbox(0, 3,
-					    fragf(_("continue with the installation"))),
-			      flowindentbox(0, 3,
-					    fragf(_("abort and quit"))),
-			      flowindentbox(0, 3,
-					    fragf(_("show information about one or more packages; the package names should follow the 'i'"))),
-			      flowindentbox(0, 3,
-					    fragf(_("show the Debian changelogs of one or more packages; the package names should follow the 'c'"))),
-			      flowindentbox(0, 3,
-					    fragf(_("toggle the display of dependency information"))),
-			      flowindentbox(0, 3,
-					    fragf(_("toggle the display of changes in package sizes"))),
-			      flowindentbox(0, 3,
-					    fragf(_("toggle the display of version numbers"))),
-			      flowindentbox(0, 3,
-					    fragf(_("try to find a reason for installing a single package, or explain why installing one package should lead to installing another package."))),
-			      flowindentbox(0, 3,
-					    fragf(_("enter the full visual interface"))),
-			      flowbox(fragf(_("You may also specify modification to the actions which will be taken.  To do so, type an action character followed by one or more package names (or patterns).  The action will be applied to all the packages that you list.  The following actions are available:"))),
-			      // FIXME: copied from
-			      // cmdline_resolver.cc, maybe this
-			      // should be placed in a common file?
-			      flowindentbox(0, 4,
-					    fragf(_("'+' to install packages"))),
-			      flowindentbox(0, 5,
-					    fragf(_("'+M' to install packages and immediately flag them as automatically installed"))),
-			      flowindentbox(0, 4,
-					    fragf(_("'-' to remove packages"))),
-			      flowindentbox(0, 4,
-					    fragf(_("'_' to purge packages"))),
-			      flowindentbox(0, 4,
-					    fragf(_("'=' to place packages on hold"))),
-			      flowindentbox(0, 4,
-					    fragf(_("':' to keep packages in their current state without placing them on hold"))),
-			      flowindentbox(0, 4,
-					    fragf(_("'&M' to mark packages as automatically installed"))),
-			      flowindentbox(0, 4,
-					    fragf(_("'&m' to mark packages as manually installed")))));
+  std::vector<cw::fragment *> fragments;
+
+  fragments.push_back(cw::fragf(_("y: %F"),
+				flowindentbox(0, 3,
+					      cw::fragf(_("continue with the installation")))));
+
+  fragments.push_back(cw::fragf(_("n: %F"),
+				flowindentbox(0, 3,
+					      cw::fragf(_("abort and quit")))));
+
+  fragments.push_back(cw::fragf(_("i: %F"),
+				flowindentbox(0, 3,
+					      cw::fragf(_("show information about one or more packages; the package names should follow the 'i'")))));
+
+  fragments.push_back(cw::fragf(_("c: %F"),
+				flowindentbox(0, 3,
+					      cw::fragf(_("show the Debian changelogs of one or more packages; the package names should follow the 'c'")))));
+
+  fragments.push_back(cw::fragf(_("d: %F"),
+				flowindentbox(0, 3,
+					      cw::fragf(_("toggle the display of dependency information")))));
+
+  fragments.push_back(cw::fragf(_("s: %F"),
+				flowindentbox(0, 3,
+					      cw::fragf(_("toggle the display of changes in package sizes")))));
+
+  fragments.push_back(cw::fragf(_("v: %F"),
+				flowindentbox(0, 3,
+					      cw::fragf(_("toggle the display of version numbers")))));
+
+  fragments.push_back(cw::fragf(_("w: %F"),
+				flowindentbox(0, 3,
+					      cw::fragf(_("try to find a reason for installing a single package, or explain why installing one package should lead to installing another package.")))));
+
+  fragments.push_back(cw::fragf(_("e: %F"),
+				flowindentbox(0, 3,
+					      cw::fragf(_("enter the full visual interface")))));
+
+  fragments.push_back(cw::fragf("\n"));
+  fragments.push_back(cwidget::flowbox(cw::fragf(_("You may also specify modification to the actions which will be taken.  To do so, type an action character followed by one or more package names (or patterns).  The action will be applied to all the packages that you list.  The following actions are available:"))));
+  fragments.push_back(cw::fragf("\n"));
+
+  // FIXME: copied from
+  // cmdline_resolver.cc, maybe this
+  // should be placed in a common file?
+  fragments.push_back(flowindentbox(0, 4,
+				    cw::fragf(_("'+' to install packages"))));
+
+  fragments.push_back(flowindentbox(0, 5,
+				    cw::fragf(_("'+M' to install packages and immediately flag them as automatically installed"))));
+  fragments.push_back(flowindentbox(0, 4,
+				    cw::fragf(_("'-' to remove packages"))));
+  fragments.push_back(flowindentbox(0, 4,
+				    cw::fragf(_("'_' to purge packages"))));
+  fragments.push_back(flowindentbox(0, 4,
+				    cw::fragf(_("'=' to place packages on hold"))));
+  fragments.push_back(flowindentbox(0, 4,
+				    cw::fragf(_("':' to keep packages in their current state without placing them on hold"))));
+  fragments.push_back(flowindentbox(0, 4,
+				    cw::fragf(_("'&M' to mark packages as automatically installed"))));
+  fragments.push_back(flowindentbox(0, 4,
+				    cw::fragf(_("'&m' to mark packages as manually installed"))));
+
+  cw::fragment *f = indentbox(2, 2, cw::sequence_fragment(fragments));
 
   out << _("Commands:") << endl;
-  out << f->layout(screen_width, screen_width, style());
+  out << f->layout(screen_width, screen_width, cwidget::style());
   delete f;
 }
 
