@@ -7,12 +7,12 @@
 
 #include "cmdline_common.h"
 
-#include <generic/util/exception.h>
+#include <cwidget/generic/util/exception.h>
 
 /** Thrown when we get EOF on stdin.  Should never be thrown
- *  to the toplevel.
+ *  to the cwidget::toplevel.
  */
-class StdinEOFException : public Exception
+class StdinEOFException : public cwidget::util::Exception
 {
 public:
   std::string errmsg() const;
