@@ -8,7 +8,10 @@
 #include <iosfwd>
 #include <string>
 
-class fragment_contents;
+namespace cwidget
+{
+  class fragment_contents;
+}
 
 /** Run the "show" operation on a single argument, presented as a string. */
 bool do_cmdline_show(std::string s, int verbose);
@@ -16,6 +19,6 @@ bool do_cmdline_show(std::string s, int verbose);
 /** The "show" user command. */
 int cmdline_show(int argc, char *argv[], int verbose);
 
-std::ostream &operator<<(std::ostream &out, const fragment_contents &contents);
+std::ostream &operator<<(std::ostream &out, const cwidget::fragment_contents &contents);
 
 #endif // CMDLINE_SHOW_H
