@@ -7,6 +7,9 @@
 
 #include "cmdline_common.h"
 
+// For download_manager::result
+#include <generic/apt/download_manager.h>
+
 void cmdline_show_pkglist(pkgvector &items);
 void cmdline_show_stringlist(strvector &items);
 
@@ -21,6 +24,11 @@ pkgCache::VerIterator cmdline_find_ver(pkgCache::PkgIterator pkg,
  */
 void ui_preview();
 
+/** Starts up the visual UI with the solution screen visible, exiting
+ *  when the UI shuts down.
+ */
+void ui_solution_screen();
+
 /** Splits the given input string into a package name/pattern and a
  *  version source.  If the input string is an output string, the
  *  function will still behave sanely.
@@ -38,4 +46,13 @@ bool cmdline_parse_source(const string &input,
 			  string &package,
 			  string &sourcestr);
 
+/** Run the given download and post-download commands using the
+ *  standard command-line UI.  Runs the preparation routine, the
+ *  actual download, and the post-download commands.
+ *
+ *  \return the success status of the post-download commands, or
+ *  failure if the process failed before they could be run.
+ */
+download_manager::result cmdline_do_download(download_manager *m);
+
 #endif // CMDLINE_UTIL_H
