@@ -43,12 +43,16 @@
 #include <generic/util/immset.h>
 #include <generic/util/util.h>
 
-#include <vscreen/fragment.h>
+#include <cwidget/fragment.h>
 
 #include <../pkg_item.h>
 
 #include <set>
 
+namespace cw = cwidget;
+using cwidget::fragf;
+using cwidget::fragment;
+
 namespace
 {
   struct compare_pkgs
@@ -85,7 +89,7 @@ namespace
     {
     }
 
-    style get_style() const
+    cw::style get_style() const
     {
       pkgCache::PkgIterator pkg;
       if(!dep.end())
@@ -96,7 +100,7 @@ namespace
       return pkg_item::pkg_style(pkg, false);
     }
 
-    fragment *description_column1_fragment() const
+    cw::fragment *description_column1_fragment() const
     {
       pkgCache::VerIterator ver;
       if(!dep.end())
@@ -109,11 +113,11 @@ namespace
       // Copy flags from "aptitude search" et al.
       //
       // This is a little crufty; the column formatting needs an overhaul.
-      column_disposition flag1 =
+      cw::column_disposition flag1 =
 	pkg_ver_columnizer::setup_column(ver, true, 0, pkg_item::pkg_columnizer::stateflag);
-      column_disposition flag2 =
+      cw::column_disposition flag2 =
 	pkg_ver_columnizer::setup_column(ver, true, 0, pkg_item::pkg_columnizer::actionflag);
-      column_disposition flag3 =
+      cw::column_disposition flag3 =
 	pkg_ver_columnizer::setup_column(ver, true, 0, pkg_item::pkg_columnizer::autoset);
 
       std::wstring rval;
@@ -130,34 +134,34 @@ namespace
       else
 	rval += flag3.text;
       rval += L' ';
-      rval += transcode(pkg.Name());
-      return text_fragment(rval);
+      rval += cw::util::transcode(pkg.Name());
+      return cw::text_fragment(rval);
     }
 
-    fragment *description_column2_fragment() const
+    cw::fragment *description_column2_fragment() const
     {
       if(!dep.end())
-	return text_fragment(const_cast<pkgCache::DepIterator &>(dep).DepType());
+	return cw::text_fragment(const_cast<pkgCache::DepIterator &>(dep).DepType());
       else
-	return text_fragment(_("Provides"));
+	return cw::text_fragment(_("Provides"));
     }
 
-    fragment *description_column3_fragment() const
+    cw::fragment *description_column3_fragment() const
     {
-      // Q: can I use a std::string and transcode on the way out instead?
+      // Q: can I use a std::string and cw::util::transcode on the way out instead?
       if(!dep.end())
 	{
 	  pkgCache::DepIterator start, end;
 	  surrounding_or(dep, start, end);
-	  return text_fragment(dep_targets(start));
+	  return cw::text_fragment(dep_targets(start));
 	}
       else
-	return text_fragment(const_cast<pkgCache::PrvIterator &>(prv).ParentPkg().Name());
+	return cw::text_fragment(const_cast<pkgCache::PrvIterator &>(prv).ParentPkg().Name());
     }
 
-    fragment *description_fragment() const
+    cw::fragment *description_fragment() const
     {
-      return fragf("%F %F %F",
+      return cw::fragf("%F %F %F",
 		   description_column1_fragment(),
 		   description_column2_fragment(),
 		   description_column3_fragment());
@@ -227,6 +231,7 @@ namespace
 	case pkgCache::Dep::Depends:
 	case pkgCache::Dep::PreDepends:
 	case pkgCache::Dep::Conflicts:
+	case pkgCache::Dep::DpkgBreaks:
 	  return true;
 	case pkgCache::Dep::Recommends:
 	  return dep_level == Recommends || dep_level == Suggests;
@@ -404,22 +409,22 @@ namespace
       return justify_target(pkg, RemoveType);
     }
 
-    fragment *description() const
+    cw::fragment *description() const
     {
       pkgCache::PkgIterator &mpkg = const_cast<pkgCache::PkgIterator &>(pkg);
 
       switch(node_type)
 	{
 	case InstallType:
-	  return fragf(_("Install(%s)"), mpkg.Name());
+	  return cw::fragf(_("Install(%s)"), mpkg.Name());
 	case RemoveType:
-	  return fragf(_("Remove(%s)"), mpkg.Name());
+	  return cw::fragf(_("Remove(%s)"), mpkg.Name());
 	case ProvidesInstall:
-	  return fragf(_("Install(%s provides %s)"),
+	  return cw::fragf(_("Install(%s provides %s)"),
 		       const_cast<pkgCache::PrvIterator &>(prv).OwnerPkg().Name(),
 		       mpkg.Name());
 	case ProvidesRemove:
-	  return fragf(_("Remove(%s provides %s)"),
+	  return cw::fragf(_("Remove(%s provides %s)"),
 		       const_cast<pkgCache::PrvIterator &>(prv).OwnerPkg().Name(),
 		       mpkg.Name());
 	}
@@ -501,40 +506,43 @@ namespace
       return justify_node(target, new_actions);
     }
 
-    fragment *description() const
+    cw::fragment *description() const
     {
-      std::vector<fragment *> rval;
-      rval.push_back(fragf("%F\n", target.description()));
-      std::vector<fragment *> col1_entries, col2_entries, col3_entries;
+      std::vector<cw::fragment *> rval;
+      rval.push_back(cw::fragf("%F\n", target.description()));
+      std::vector<cw::fragment *> col1_entries, col2_entries, col3_entries;
       for(imm::set<justify_action>::const_iterator it = actions.begin();
 	  it != actions.end(); ++it)
 	{
-	  col1_entries.push_back(fragf("%F | \n", it->description_column1_fragment()));
-	  col2_entries.push_back(fragf("%F\n", it->description_column2_fragment()));
-	  col3_entries.push_back(fragf("%F\n", it->description_column3_fragment()));
+	  col1_entries.push_back(cw::hardwrapbox(cw::fragf("%F | \n", it->description_column1_fragment())));
+	  col2_entries.push_back(cw::hardwrapbox(cw::fragf("%F\n", it->description_column2_fragment())));
+	  col3_entries.push_back(cw::hardwrapbox(cw::fragf("%F\n", it->description_column3_fragment())));
 	}
+
+      using cw::fragment_column_entry;
+
       std::vector<fragment_column_entry> columns;
-      columns.push_back(fragment_column_entry(false, true, 0, fragment_column_entry::top, sequence_fragment(col1_entries)));
+      columns.push_back(fragment_column_entry(false, true, 0, fragment_column_entry::top, col1_entries));
       columns.push_back(fragment_column_entry(false, false, 1, fragment_column_entry::top, NULL)),
-      columns.push_back(fragment_column_entry(false, true, 0, fragment_column_entry::top, sequence_fragment(col2_entries)));
+      columns.push_back(fragment_column_entry(false, true, 0, fragment_column_entry::top, col2_entries));
       columns.push_back(fragment_column_entry(false, false, 1, fragment_column_entry::top, NULL)),
-      columns.push_back(fragment_column_entry(false, true, 0, fragment_column_entry::top, sequence_fragment(col3_entries)));
+      columns.push_back(fragment_column_entry(false, true, 0, fragment_column_entry::top, col3_entries));
       rval.push_back(fragment_columns(columns));
-      return sequence_fragment(rval);
+      return cw::sequence_fragment(rval);
     }
   };
 
-  fragment *print_dep(pkgCache::DepIterator dep)
+  cw::fragment *print_dep(pkgCache::DepIterator dep)
   {
     if(dep.TargetVer() != NULL)
-      return fragf("%s %s %s (%s %s)",
+      return cw::fragf("%s %s %s (%s %s)",
 		   dep.ParentPkg().Name(),
 		   dep.DepType(),
 		   dep.TargetPkg().Name(),
 		   dep.CompType(),
 		   dep.TargetVer());
     else
-      return fragf("%s %s %s",
+      return cw::fragf("%s %s %s",
 		   dep.ParentPkg().Name(),
 		   dep.DepType(),
 		   dep.TargetPkg().Name());
@@ -564,7 +572,7 @@ namespace
       {
 	// If we walked through a Provides, we can only look at conflicts.
 	if(!params.get_allow_choices() &&
-	   dep->Type != pkgCache::Dep::Conflicts &&
+	   !is_conflict(dep->Type) &&
 	   is_provides())
 	  continue;
 
@@ -572,7 +580,8 @@ namespace
 	  pkgCache::DepIterator start, end;
 	  // Drop ORs if choices are disallowed.  Note that ORs are
 	  // meaningless for conflicts, so we ignore them there.
-	  if(!params.get_allow_choices() && dep->Type != pkgCache::Dep::Conflicts)
+	  if(!params.get_allow_choices() &&
+	     !is_conflict(dep->Type))
 	    {
 	      // Check if we're in an OR by checking whether either
 	      // (a) the OR flag is set, or (b) this isn't the first
@@ -590,14 +599,14 @@ namespace
 
 	if(verbosity > 1)
 	  {
-	    std::auto_ptr<fragment> tmp(fragf(_("    ++ Examining %s\n"), print_dep(dep)));
-	    std::cout << tmp->layout(screen_width, screen_width, style());
+	    std::auto_ptr<cw::fragment> tmp(cw::fragf(_("    ++ Examining %F\n"), print_dep(dep)));
+	    std::cout << tmp->layout(screen_width, screen_width, cw::style());
 	  }
 
 	if(is_remove())
 	  {
 	    // Remove, ProvidesRemove nodes take this.
-	    if(dep->Type != pkgCache::Dep::Conflicts)
+	    if(!is_conflict(dep->Type))
 	      {
 		if(verbosity > 1)
 		  std::cout << _("    ++   --> skipping, not a conflict\n");
@@ -607,7 +616,7 @@ namespace
 	else
 	  {
 	    // Install, ProvidesInstall nodes take this.
-	    if(dep->Type == pkgCache::Dep::Conflicts)
+	    if(is_conflict(dep->Type))
 	      {
 		if(verbosity > 1)
 		  std::cout << _("    ++   --> skipping conflict\n");
@@ -810,7 +819,7 @@ namespace
       if(first_iteration)
 	{
 	  if(verbosity > 1)
-	    std::cout << ssprintf(_("Starting search with parameters %s\n"),
+	    std::cout << ssprintf(_("Starting search with parameters %ls\n"),
 				  params.description().c_str());
 	  first_iteration = false;
 	}
@@ -825,11 +834,11 @@ namespace
 
 	  if(verbosity > 1)
 	    {
-	      std::auto_ptr<fragment> f(fragf("Search for %F\n",
+	      std::auto_ptr<cw::fragment> f(cw::fragf("Search for %F\n",
 					      front.description()));
 	      std::cout << f->layout(screen_width,
 				     screen_width,
-				     style());
+				     cw::style());
 	    }
 
 
@@ -849,7 +858,9 @@ namespace
 	    for(std::vector<pkg_matcher *>::const_iterator it = leaves.begin();
 		!reached_leaf && it != leaves.end(); ++it)
 	      {
-		if((*it)->matches(frontpkg, frontver))
+		if((*it)->matches(frontpkg, frontver,
+				  *apt_cache_file,
+				  *apt_package_records))
 		  reached_leaf = true;
 	      }
 	  if(reached_leaf)
@@ -893,13 +904,17 @@ namespace
     }
 
     bool matches(const pkgCache::PkgIterator &pkg,
-		 const pkgCache::VerIterator &ver)
+		 const pkgCache::VerIterator &ver,
+		 aptitudeDepCache &cache,
+		 pkgRecords &records)
     {
       return pkg == match_pkg;
     }
 
     pkg_match_result *get_match(const pkgCache::PkgIterator &pkg,
-				const pkgCache::VerIterator &ver)
+				const pkgCache::VerIterator &ver,
+				aptitudeDepCache &cache,
+				pkgRecords &records)
     {
       if(pkg == match_pkg)
 	return new const_name_result(pkg.Name());
@@ -909,13 +924,13 @@ namespace
   };
 }
 
-fragment *do_why(const std::vector<pkg_matcher *> &leaves,
+cw::fragment *do_why(const std::vector<pkg_matcher *> &leaves,
 		 const pkgCache::PkgIterator &root,
 		 int verbosity,
 		 bool root_is_removal,
 		 bool &success)
 {
-  std::vector<fragment *> rval;
+  std::vector<cw::fragment *> rval;
   success = true;
 
   std::vector<search_params> searches;
@@ -1033,33 +1048,33 @@ fragment *do_why(const std::vector<pkg_matcher *> &leaves,
 	  if(first)
 	    first = false;
 	  else
-	    std::cout << std::endl;
+	    rval.push_back(cw::newline_fragment());
 
 	  if(results.empty())
-	    return fragf(_("The package \"%s\" is a starting point of the search.\n"),
+	    return cw::fragf(_("The package \"%s\" is a starting point of the search.\n"),
 			 root.Name());
 	  else
 	    {
-	      std::vector<fragment *> col1_entries, col2_entries, col3_entries;
+	      std::vector<cw::fragment *> col1_entries, col2_entries, col3_entries;
 	      for(std::vector<justify_action>::const_iterator it = results.begin();
 		  it != results.end(); ++it)
 		{
-		  col1_entries.push_back(style_fragment(fragf("%F\n", it->description_column1_fragment()),
-							it->get_style()));
-		  col2_entries.push_back(style_fragment(fragf("%F\n", it->description_column2_fragment()),
-							it->get_style()));
-		  col3_entries.push_back(style_fragment(fragf("%F\n", it->description_column3_fragment()),
-							it->get_style()));
+		  col1_entries.push_back(cw::hardwrapbox(cw::style_fragment(cw::fragf("%F\n", it->description_column1_fragment()),
+									it->get_style())));
+		  col2_entries.push_back(cw::hardwrapbox(cw::style_fragment(cw::fragf("%F\n", it->description_column2_fragment()),
+									it->get_style())));
+		  col3_entries.push_back(cw::hardwrapbox(cw::style_fragment(cw::fragf("%F\n", it->description_column3_fragment()),
+									it->get_style())));
 		}
+
+	      using cw::fragment_column_entry;
+
 	      std::vector<fragment_column_entry> columns;
-	      fragment *col1_contents = sequence_fragment(col1_entries);
-	      fragment *col2_contents = sequence_fragment(col2_entries);
-	      fragment *col3_contents = sequence_fragment(col3_entries);
 	      columns.push_back(fragment_column_entry(false,
 						      true,
 						      0,
 						      fragment_column_entry::top,
-						      col1_contents));
+						      col1_entries));
 	      columns.push_back(fragment_column_entry(false,
 						      false,
 						      1,
@@ -1069,7 +1084,7 @@ fragment *do_why(const std::vector<pkg_matcher *> &leaves,
 						      true,
 						      0,
 						      fragment_column_entry::top,
-						      col2_contents));
+						      col2_entries));
 	      columns.push_back(fragment_column_entry(false,
 						      false,
 						      1,
@@ -1079,8 +1094,8 @@ fragment *do_why(const std::vector<pkg_matcher *> &leaves,
 						      true,
 						      0,
 						      fragment_column_entry::top,
-						      col3_contents));
-	      fragment *solution_fragment(fragment_columns(columns));
+						      col3_entries));
+	      cw::fragment *solution_fragment(cw::fragment_columns(columns));
 
 	      if(verbosity < 1)
 		return solution_fragment;
@@ -1095,12 +1110,12 @@ fragment *do_why(const std::vector<pkg_matcher *> &leaves,
       success = false;
 
       if(root_is_removal)
-	return fragf(_("No justification for removing %s could be constructed.\n"), root.Name());
+	return cw::fragf(_("No justification for removing %s could be constructed.\n"), root.Name());
       else
-	return fragf(_("No justification for %s could be constructed.\n"), root.Name());
+	return cw::fragf(_("No justification for %s could be constructed.\n"), root.Name());
     }
   else
-    return sequence_fragment(rval);
+    return cw::sequence_fragment(rval);
 }
 
 int do_why(const std::vector<pkg_matcher *> &leaves,
@@ -1109,16 +1124,16 @@ int do_why(const std::vector<pkg_matcher *> &leaves,
 	   bool root_is_removal)
 {
   bool success = false;
-  std::auto_ptr<fragment> f(do_why(leaves, root, verbosity, root_is_removal,
+  std::auto_ptr<cw::fragment> f(do_why(leaves, root, verbosity, root_is_removal,
 				   success));
   update_screen_width();
   // TODO: display each result as we find it.
-  std::cout << f->layout(screen_width, screen_width, style());
+  std::cout << f->layout(screen_width, screen_width, cw::style());
 
   return success ? 0 : 1;
 }
 
-fragment *do_why(const std::vector<pkg_matcher *> &leaves,
+cw::fragment *do_why(const std::vector<pkg_matcher *> &leaves,
 		 const pkgCache::PkgIterator &root,
 		 bool find_all,
 		 bool root_is_removal,
@@ -1158,7 +1173,7 @@ bool interpret_why_args(const std::vector<std::string> &args,
   return !parsing_arguments_failed;
 }
 
-fragment *do_why(const std::vector<std::string> &arguments,
+cw::fragment *do_why(const std::vector<std::string> &arguments,
 		 const std::string &root,
 		 int verbosity,
 		 bool root_is_removal,
@@ -1168,7 +1183,7 @@ fragment *do_why(const std::vector<std::string> &arguments,
 
   pkgCache::PkgIterator pkg((*apt_cache_file)->FindPkg(root.c_str()));
   if(pkg.end())
-    return fragf(_("No package named \"%s\" exists."), root.c_str());
+    return cw::fragf(_("No package named \"%s\" exists."), root.c_str());
 
   std::vector<pkg_matcher *> matchers;
   if(!interpret_why_args(arguments, matchers))
@@ -1176,17 +1191,17 @@ fragment *do_why(const std::vector<std::string> &arguments,
       for(std::vector<pkg_matcher *>::const_iterator it = matchers.begin();
 	  it != matchers.end(); ++it)
 	delete *it;
-      return text_fragment(_("Unable to parse some match patterns."));
+      return cw::text_fragment(_("Unable to parse some match patterns."));
     }
 
-  fragment *rval = do_why(matchers, pkg, verbosity, root_is_removal, success);
+  cw::fragment *rval = do_why(matchers, pkg, verbosity, root_is_removal, success);
   for(std::vector<pkg_matcher *>::const_iterator it = matchers.begin();
       it != matchers.end(); ++it)
     delete *it;
   return rval;
 }
 
-fragment *do_why(const std::vector<std::string> &leaves,
+cw::fragment *do_why(const std::vector<std::string> &leaves,
 		 const std::string &root,
 		 bool find_all,
 		 bool root_is_removal,
@@ -1249,7 +1264,8 @@ int cmdline_why(int argc, char *argv[],
       else
 	{
 	  matchers.push_back(m);
-	  if(!pkg.end() && m->matches(pkg, pkg.CurrentVer()))
+	  if(!pkg.end() && m->matches(pkg, pkg.CurrentVer(),
+				      *apt_cache_file, *apt_package_records))
 	    {
 	      printf(_("The package \"%s\" is manually installed.\n"),
 		     pkg.Name());
