@@ -24,19 +24,22 @@
 
 #include <apt-pkg/pkgcache.h>
 
-class fragment;
+namespace cwidget
+{
+  class fragment;
+}
 
 /** Parses the given description string according to the standard
  *  formatting rules.
  *
  *  \param desc a Description tag to parse
- *  \return a fragment representing that description
+ *  \return a cwidget::fragment representing that description
  */
-fragment *make_desc_fragment(const std::wstring &desc);
+cwidget::fragment *make_desc_fragment(const std::wstring &desc);
 
-/** \return a fragment listing the tags of the given package, or \b
+/** \return a cwidget::fragment listing the tags of the given package, or \b
  *  NULL if there are no tags.
  */
-fragment *make_tags_fragment(const pkgCache::PkgIterator &pkg);
+cwidget::fragment *make_tags_fragment(const pkgCache::PkgIterator &pkg);
 
 #endif
