@@ -25,30 +25,36 @@
 #include "download_item.h"
 #include "ui.h"
 
-#include <generic/util/eassert.h>
+#include <cwidget/generic/util/eassert.h>
 #include <signal.h>
 
 #include <apt-pkg/strutl.h>
 #include <apt-pkg/acquire-worker.h>
 
-#include <vscreen/transcode.h>
-#include <vscreen/vscreen.h>
-#include <vscreen/vs_util.h>
+#include <cwidget/generic/util/transcode.h>
+#include <cwidget/toplevel.h>
+#include <cwidget/dialogs.h>
 
 #include <sigc++/adaptors/bind.h>
 #include <sigc++/functors/ptr_fun.h>
 
 #include <generic/util/mut_fun.h>
 
+namespace cw = cwidget;
+namespace cwidget
+{
+  using namespace widgets;
+}
+
 static void set_and_exit(bool &target, bool val)
 {
   target=val;
-  vscreen_exitmain();
+  cw::toplevel::exitmain();
 }
 
 bool download_screen::MediaChange(string Media, string Drive)
 {
-  vs_widget_ref tmpref(this);
+  cw::widget_ref tmpref(this);
 
   char buf[512];
 
@@ -58,23 +64,23 @@ bool download_screen::MediaChange(string Media, string Drive)
 
   bool rval=true;
 
-  popup_widget(vs_dialog_yesno(transcode(buf),
-			       arg(sigc::bind(sigc::ptr_fun(set_and_exit),
-					      rval, true)),
-			       transcode(_("Continue")),
-			       arg(sigc::bind(sigc::ptr_fun(set_and_exit),
-					      rval, false)),
-			       transcode(_("Abort")),
-			       get_style("MediaChange")));
+  popup_widget(cw::dialogs::yesno(cw::util::transcode(buf),
+				  cw::util::arg(sigc::bind(sigc::ptr_fun(set_and_exit),
+						 rval, true)),
+				  W_("Continue"),
+				  cw::util::arg(sigc::bind(sigc::ptr_fun(set_and_exit),
+						 rval, false)),
+				  W_("Abort"),
+				  cw::get_style("MediaChange")));
 
-  vscreen_mainloop();  // Eeeeeek!  Recursive mainloop!  I'm afraid..
+  cw::toplevel::mainloop();  // Eeeeeek!  Recursive mainloop!  I'm afraid..
 
   return rval;
 }
 
 void download_screen::IMSHit(pkgAcquire::ItemDesc &itmdesc)
 {
-  vs_widget_ref tmpref(this);
+  cw::widget_ref tmpref(this);
 
   downloadmap::iterator found=active_items.find(itmdesc.Owner);
 
@@ -87,13 +93,13 @@ void download_screen::IMSHit(pkgAcquire::ItemDesc &itmdesc)
     }
   else
     found->second->download_done(true);
-  vscreen_update();
-  vscreen_tryupdate();
+  cw::toplevel::update();
+  cw::toplevel::tryupdate();
 }
 
 void download_screen::Fetch(pkgAcquire::ItemDesc &itmdesc)
 {
-  vs_widget_ref tmpref(this);
+  cw::widget_ref tmpref(this);
 
   downloadmap::iterator found=active_items.find(itmdesc.Owner);
 
@@ -105,13 +111,13 @@ void download_screen::Fetch(pkgAcquire::ItemDesc &itmdesc)
       sync_bounds();
     }
 
-  vscreen_update();
-  vscreen_tryupdate();
+  cw::toplevel::update();
+  cw::toplevel::tryupdate();
 }
 
 void download_screen::Done(pkgAcquire::ItemDesc &itmdesc)
 {
-  vs_widget_ref tmpref(this);
+  cw::widget_ref tmpref(this);
 
   downloadmap::iterator found=active_items.find(itmdesc.Owner);
   if(found==active_items.end())
@@ -127,26 +133,26 @@ void download_screen::Done(pkgAcquire::ItemDesc &itmdesc)
       found->second->set_worker(NULL);
     }
 
-  vscreen_update();
-  vscreen_tryupdate();
+  cw::toplevel::update();
+  cw::toplevel::tryupdate();
 }
 
 void download_screen::Fail(pkgAcquire::ItemDesc &itmdesc)
 {
-  vs_widget_ref tmpref(this);
+  cw::widget_ref tmpref(this);
 
   downloadmap::iterator found=active_items.find(itmdesc.Owner);
   if(found!=active_items.end())
     found->second->set_worker(NULL);
 
   // Nothing really to do??
-  vscreen_update();
-  vscreen_tryupdate();
+  cw::toplevel::update();
+  cw::toplevel::tryupdate();
 }
 
 bool download_screen::Pulse(pkgAcquire *Owner)
 {
-  vs_widget_ref tmpref(this);
+  cw::widget_ref tmpref(this);
 
   pkgAcquireStatus::Pulse(Owner);
 
@@ -156,24 +162,24 @@ bool download_screen::Pulse(pkgAcquire *Owner)
 	get_itm(*i->CurrentItem)->set_worker(i);
     }
 
-  vscreen_poll();
+  cw::toplevel::poll();
 
-  vscreen_update();
-  vscreen_tryupdate();
+  cw::toplevel::update();
+  cw::toplevel::tryupdate();
 
   return !cancelled;
 }
 
 void download_screen::Start()
 {
-  vs_widget_ref tmpref(this);
+  cw::widget_ref tmpref(this);
 
   pkgAcquireStatus::Start();
 }
 
 void download_screen::Stop()
 {
-  vs_widget_ref tmpref(this);
+  cw::widget_ref tmpref(this);
 
   char buf[256];
 
@@ -181,10 +187,10 @@ void download_screen::Stop()
 
   snprintf(buf, 256, _("Downloaded %sB in %ss (%sB/s)."), SizeToStr(FetchedBytes).c_str(), TimeToStr(ElapsedTime).c_str(), SizeToStr(CurrentCPS).c_str());
 
-  popup_widget(vs_dialog_ok(transcode(buf),
-			    arg(sigc::ptr_fun(vscreen_exitmain))));
+  popup_widget(cw::dialogs::ok(cw::util::transcode(buf),
+			       cw::util::arg(sigc::ptr_fun(cw::toplevel::exitmain))));
 
-  vscreen_mainloop();
+  cw::toplevel::mainloop();
 
   destroy();
 }
@@ -193,7 +199,7 @@ void download_screen::Stop()
 void download_screen::paint_status()
 {
   if(finished)
-    vs_tree::paint_status();
+    cw::tree::paint_status();
   else
     {
       int width,height;
@@ -230,14 +236,14 @@ void download_screen::paint_status()
 }
 #endif
 
-bool download_screen::handle_key(const key &k)
+bool download_screen::handle_key(const cw::config::key &k)
 {
-  vs_widget_ref tmpref(this);
+  cw::widget_ref tmpref(this);
 
-  if(global_bindings.key_matches(k, "Quit"))
+  if(cw::config::global_bindings.key_matches(k, "Quit"))
     cancelled=true;
   else
-    return vs_tree::handle_key(k);
+    return cw::tree::handle_key(k);
 
   return true;
 }
