@@ -31,9 +31,12 @@
 #include "tags.h"
 #include "tasks.h"
 
-#include <generic/util/undo.h>
+#include <cwidget/generic/util/eassert.h>
+#include <cwidget/generic/util/transcode.h>
+
 #include <generic/util/util.h>
-#include <vscreen/transcode.h>
+
+#include <generic/util/undo.h>
 
 #include <apt-pkg/configuration.h>
 #include <apt-pkg/depcache.h>
@@ -45,7 +48,6 @@
 
 #include <fstream>
 
-#include <generic/util/eassert.h>
 #include <signal.h>
 #include <unistd.h>
 #include <sys/stat.h>
@@ -150,7 +152,7 @@ void apt_preinit()
 
   cache_closed.connect(sigc::ptr_fun(&reset_surrounding_or_memoization));
 
-  apt_dumpcfg("Aptitude");
+  apt_dumpcfg(PACKAGE);
 
   apt_undos=new undo_list;
 }
@@ -359,10 +361,11 @@ pkg_hier *get_user_pkg_hier()
   return user_pkg_hier;
 }
 
-pkg_action_state find_pkg_state(pkgCache::PkgIterator pkg)
+pkg_action_state find_pkg_state(pkgCache::PkgIterator pkg,
+				aptitudeDepCache &cache)
 {
-  aptitudeDepCache::StateCache &state=(*apt_cache_file)[pkg];
-  aptitudeDepCache::aptitude_state &extstate=(*apt_cache_file)->get_ext_state(pkg);
+  aptitudeDepCache::StateCache &state = cache[pkg];
+  aptitudeDepCache::aptitude_state &extstate = cache.get_ext_state(pkg);
 
   if(state.InstBroken())
     return pkg_broken;
@@ -408,7 +411,12 @@ pkg_action_state find_pkg_state(pkgCache::PkgIterator pkg)
     return pkg_reinstall;
   // States where --configure fixes things.
   else if(pkg->CurrentState == pkgCache::State::UnPacked ||
-	  pkg->CurrentState == pkgCache::State::HalfConfigured)
+	  pkg->CurrentState == pkgCache::State::HalfConfigured
+#ifdef APT_HAS_TRIGGERS
+	  || pkg->CurrentState == pkgCache::State::TriggersAwaited
+	  || pkg->CurrentState == pkgCache::State::TriggersPending
+#endif
+	  )
     return pkg_unconfigured;
 
   return pkg_unchanged;
@@ -864,9 +872,10 @@ bool is_interesting_dep(const pkgCache::DepIterator &d,
     }
 }
 
-std::wstring get_short_description(const pkgCache::VerIterator &ver)
+std::wstring get_short_description(const pkgCache::VerIterator &ver,
+				   pkgRecords *records)
 {
-  if(ver.end() || ver.FileList().end() || apt_package_records == NULL)
+  if(ver.end() || ver.FileList().end() || records == NULL)
     return std::wstring();
 
 #ifndef HAVE_DDTP
@@ -875,7 +884,7 @@ std::wstring get_short_description(const pkgCache::VerIterator &ver)
   if(vf.end())
     return std::wstring();
   else
-    return transcode(apt_package_records->Lookup(vf).ShortDesc());
+    return cw::util::transcode(records->Lookup(vf).ShortDesc());
 #else
   pkgCache::DescIterator d = ver.TranslatedDescription();
 
@@ -887,16 +896,17 @@ std::wstring get_short_description(const pkgCache::VerIterator &ver)
   if(df.end())
     return std::wstring();
   else
-    // apt "helpfully" transcodes the description for us, instead of
+    // apt "helpfully" cw::util::transcodes the description for us, instead of
     // providing direct access to it.  So I need to assume that the
     // description is encoded in the current locale.
-    return transcode(apt_package_records->Lookup(df).ShortDesc());
+    return cwidget::util::transcode(records->Lookup(df).ShortDesc());
 #endif
 }
 
-std::wstring get_long_description(const pkgCache::VerIterator &ver)
+std::wstring get_long_description(const pkgCache::VerIterator &ver,
+				  pkgRecords *records)
 {
-  if(ver.end() || ver.FileList().end() || apt_package_records == NULL)
+  if(ver.end() || ver.FileList().end() || records == NULL)
     return std::wstring();
 
 #ifndef HAVE_DDTP
@@ -905,7 +915,7 @@ std::wstring get_long_description(const pkgCache::VerIterator &ver)
   if(vf.end())
     return std::wstring();
   else
-    return transcode(apt_package_records->Lookup(vf).LongDesc());
+    return cw::util::transcode(records->Lookup(vf).LongDesc());
 #else
   pkgCache::DescIterator d = ver.TranslatedDescription();
 
@@ -917,6 +927,6 @@ std::wstring get_long_description(const pkgCache::VerIterator &ver)
   if(df.end())
     return std::wstring();
   else
-    return transcode(apt_package_records->Lookup(df).LongDesc());
+    return cwidget::util::transcode(records->Lookup(df).LongDesc());
 #endif
 }
