@@ -47,7 +47,7 @@
 #include <errno.h>
 #include <sys/stat.h>
 
-#include <generic/util/eassert.h>
+#include <cwidget/generic/util/eassert.h>
 
 #include <sigc++/adaptors/bind.h>
 #include <sigc++/functors/mem_fun.h>
@@ -184,7 +184,8 @@ aptitudeDepCache::action_group::~action_group()
 
 aptitudeDepCache::aptitudeDepCache(pkgCache *Cache, Policy *Plcy)
   :pkgDepCache(Cache, Plcy), dirty(false), read_only(true),
-   package_states(NULL), lock(-1), group_level(0)
+   package_states(NULL), lock(-1), group_level(0),
+   new_package_count(0), records(NULL)
 {
   // When the "install recommended packages" flag changes, collect garbage.
 #if 0
@@ -213,6 +214,7 @@ bool aptitudeDepCache::Init(OpProgress *Prog, bool WithLock, bool do_initselecti
 
 aptitudeDepCache::~aptitudeDepCache()
 {
+  delete records;
   delete[] package_states;
 
   if(lock!=-1)
@@ -236,6 +238,8 @@ bool aptitudeDepCache::build_selection_list(OpProgress &Prog, bool WithLock,
   if(!pkgDepCache::Init(&Prog))
     return false;
 
+  records = new pkgRecords(*this);
+
   // This is necessary so that the Garbage flags are initialized.
   // Some of the Mark* methods perturb the Auto flag in largely
   // uncontrollable ways, and one defense against this is to get
@@ -252,6 +256,7 @@ bool aptitudeDepCache::build_selection_list(OpProgress &Prog, bool WithLock,
       package_states[i].reinstall=false;
       package_states[i].remove_reason=manual;
       package_states[i].selection_state = pkgCache::State::Unknown;
+      package_states[i].previously_auto_package = false;
     }
 
   if(WithLock && lock==-1)
@@ -326,6 +331,11 @@ bool aptitudeDepCache::build_selection_list(OpProgress &Prog, bool WithLock,
 	      section.FindFlag("Upgrade", tmp, 1);
 	      pkg_state.upgrade=(tmp==1);
 
+	      unsigned long auto_new_install = 0;
+	      section.FindFlag("Auto-New-Install", auto_new_install, 1);
+	      if(auto_new_install)
+		pkg_state.previously_auto_package = true;
+
 	      // The install reason is much more important to preserve
 	      // from previous versions, so support the outdated name
 	      // for it.
@@ -334,10 +344,7 @@ bool aptitudeDepCache::build_selection_list(OpProgress &Prog, bool WithLock,
 			      section.FindI("Last-Change", manual));
 
 	      if(install_reason != manual)
-		{
-		  MarkAuto(pkg, true);
-		  dirty = true;
-		}
+		pkg_state.previously_auto_package = true;
 
 	      pkg_state.remove_reason=(changed_reason)
 		section.FindI("Remove-Reason", manual);
@@ -460,6 +467,12 @@ bool aptitudeDepCache::build_selection_list(OpProgress &Prog, bool WithLock,
 	  break;
 	}
 
+      if(estate.previously_auto_package)
+	{
+	  MarkAuto(i, true);
+	  dirty = true;
+	}
+
       ++num;
       Prog.OverallProgress(num, Head().PackageCount, 1, _("Initializing package states"));
     }
@@ -603,6 +616,11 @@ bool aptitudeDepCache::save_selection_list(OpProgress &prog,
 	    bool upgrade=(!i.CurrentVer().end()) && state.Install();
 	    string upgradestr=upgrade ? "Upgrade: yes\n" : "";
 
+	    bool auto_new_install = (i.CurrentVer().end() &&
+				     state.Install() &&
+				     ((state.Flags & Flag::Auto) != 0));
+	    string autostr = auto_new_install ? "Auto-New-Install: yes\n" : "";
+
 	    string tailstr;
 
 	    if(state.Install() &&
@@ -613,13 +631,14 @@ bool aptitudeDepCache::save_selection_list(OpProgress &prog,
 
 	    len=snprintf(buf,
 			 400,
-			 "Package: %s\nUnseen: %s\nState: %i\nDselect-State: %i\nRemove-Reason: %i\n%s%s%s\n",
+			 "Package: %s\nUnseen: %s\nState: %i\nDselect-State: %i\nRemove-Reason: %i\n%s%s%s%s\n",
 			 i.Name(),
 			 estate.new_package?"yes":"no",
 			 estate.selection_state,
 			 i->SelectedState,
 			 estate.remove_reason,
 			 upgradestr.c_str(),
+			 autostr.c_str(),
 			 forbidstr.c_str(),
 			 tailstr.c_str());
 	    if(len>=399)
@@ -1411,6 +1430,7 @@ void aptitudeDepCache::apply_solution(const generic_solution<aptitude_universe>
     {
       pkgCache::PkgIterator pkg=i->first.get_pkg();
       pkgCache::VerIterator curver=pkg.CurrentVer();
+      pkgCache::VerIterator instver = (*apt_cache_file)[pkg].InstVerIter(*apt_cache_file);
       pkgCache::VerIterator actionver=i->second.ver.get_ver();
 
       // Check what type of action it is.
@@ -1428,7 +1448,14 @@ void aptitudeDepCache::apply_solution(const generic_solution<aptitude_universe>
 	{
 	  set_candidate_version(actionver, NULL);
 	  internal_mark_install(pkg, false, false);
-	  MarkAuto(pkg, true);
+	  // Mark the package as automatic iff it isn't currently
+	  // going to be installed.  Thus packages that are currently
+	  // manually installed don't get marked as auto, packages
+	  // that are going to be manually installed don't get marked
+	  // as auto, but packages that are being removed *do* get
+	  // marked as auto.
+	  if(instver.end())
+	    MarkAuto(pkg, true);
 	}
     }
 }
@@ -1547,6 +1574,9 @@ bool aptitudeDepCache::MarkFollowsSuggests()
 
 class AptitudeInRootSetFunc : public pkgDepCache::InRootSetFunc
 {
+  /** \brief A pointer to the cache in which we're matching. */
+  aptitudeDepCache &cache;
+
   /** A matcher if one could be created; otherwise NULL. */
   pkg_matcher *m;
 
@@ -1558,8 +1588,9 @@ class AptitudeInRootSetFunc : public pkgDepCache::InRootSetFunc
    */
   pkgDepCache::InRootSetFunc *chain;
 public:
-  AptitudeInRootSetFunc(pkgDepCache::InRootSetFunc *_chain)
-    : m(NULL), constructedSuccessfully(false), chain(NULL)
+  AptitudeInRootSetFunc(pkgDepCache::InRootSetFunc *_chain,
+			aptitudeDepCache &_cache)
+    : cache(_cache), m(NULL), constructedSuccessfully(false), chain(NULL)
   {
     std::string matchterm = aptcfg->Find(PACKAGE "::Keep-Unused-Pattern", "~nlinux-image-.*");
     if(matchterm.empty()) // Bug-compatibility with old versions.
@@ -1585,7 +1616,8 @@ public:
 
   bool InRootSet(const pkgCache::PkgIterator &pkg)
   {
-    if(m != NULL && m->matches(pkg))
+    pkgRecords &records(cache.get_records());
+    if(m != NULL && m->matches(pkg, cache, records))
       return true;
     else
       return chain != NULL && chain->InRootSet(pkg);
@@ -1602,7 +1634,7 @@ pkgDepCache::InRootSetFunc *aptitudeDepCache::GetRootSetFunc()
 {
   InRootSetFunc *superFunc = pkgDepCache::GetRootSetFunc();
 
-  AptitudeInRootSetFunc *f = new AptitudeInRootSetFunc(superFunc);
+  AptitudeInRootSetFunc *f = new AptitudeInRootSetFunc(superFunc, *this);
 
   if(f->wasConstructedSuccessfully())
     return f;
