@@ -1,6 +1,6 @@
 // download_install_manager.cc
 //
-//   Copyright (C) 2005-2006 Daniel Burrows
+//   Copyright (C) 2005-2007 Daniel Burrows
 //
 //   This program is free software; you can redistribute it and/or
 //   modify it under the terms of the GNU General Public License as
@@ -62,6 +62,10 @@ bool download_install_manager::prepare(OpProgress &progress,
 
   progress.Done();
 
+  // Abort here so we don't spew random messages below.
+  if(_error->PendingError())
+    return false;
+
   // Lock the archive directory..
   FileFd lock;
   if(aptcfg->FindB("Debug::NoLocking", false) == false)
@@ -143,14 +147,13 @@ download_manager::result download_install_manager::execute_install_run(pkgAcquir
 
   pthread_sigmask(SIG_UNBLOCK, &allsignals, &oldsignals);
   pkgPackageManager::OrderResult pmres = pm->DoInstall(aptcfg->FindI("APT::Status-Fd", -1));
-  pthread_sigmask(SIG_SETMASK, &oldsignals, NULL);
 
   switch(pmres)
     {
     case pkgPackageManager::Failed:
       _error->DumpErrors();
       cerr << _("A package failed to install.  Trying to recover:") << endl;
-      system("dpkg --configure -a");
+      system("DPKG_NO_TSTP=1 dpkg --configure -a");
       _error->Discard();
       
       rval = failure;
@@ -163,6 +166,7 @@ download_manager::result download_install_manager::execute_install_run(pkgAcquir
       break;
     }
 
+  pthread_sigmask(SIG_SETMASK, &oldsignals, NULL);
   post_install_hook(pmres);
 
   fetcher->Shutdown();
@@ -192,12 +196,20 @@ download_manager::result download_install_manager::finish(pkgAcquire::RunResult
       if(log != NULL)
 	log->Complete();
 
+      // We absolutely need to do this here.  Yes, it slows things
+      // down, but without this we get stuff like #429388 due to
+      // inconsistencies between aptitude's state file and the real
+      // world.
+      //
+      // This implicitly updates the package state file on disk.
+      apt_load_cache(&progress, true);
+
       if(aptcfg->FindB(PACKAGE "::Forget-New-On-Install", false))
 	{
-	  apt_load_cache(&progress, true);
 	  if(apt_cache_file != NULL)
 	    {
 	      (*apt_cache_file)->forget_new(NULL);
+	      (*apt_cache_file)->save_selection_list(progress);
 	      post_forget_new_hook();
 	    }
 	}
