@@ -20,10 +20,10 @@
 #ifndef EXCEPTIONS_H
 #define EXCEPTIONS_H
 
-#include <generic/util/exception.h>
+#include <cwidget/generic/util/exception.h>
 
 /** Generic errors in the problem resolver. */
-class ProblemResolverError : public Exception {
+class ProblemResolverError : public cwidget::util::Exception {
 };
 
 /** An exception indicating that no more solutions are available. */
