@@ -22,14 +22,14 @@
 
 #include "menu_redirect.h"
 
-#include <vscreen/vs_editline.h>
-#include <vscreen/vs_text_layout.h>
+#include <cwidget/widgets/editline.h>
+#include <cwidget/widgets/text_layout.h>
 
-class menu_text_layout : public vs_text_layout, public menu_redirect
+class menu_text_layout : public cwidget::widgets::text_layout, public menu_redirect
 {
   std::wstring last_search;
   bool last_search_forward;
-  vs_editline::history_list search_history;
+  cwidget::widgets::editline::history_list search_history;
 
   menu_text_layout(const menu_text_layout &other);
 
@@ -50,26 +50,26 @@ protected:
   {
   }
 
-  menu_text_layout(fragment *f)
-    : vs_text_layout(f), last_search_forward(true)
+  menu_text_layout(cwidget::fragment *f)
+    : cwidget::widgets::text_layout(f), last_search_forward(true)
   {
   }
 public:
-  static ref_ptr<menu_text_layout> create()
+  static cwidget::util::ref_ptr<menu_text_layout> create()
   {
-    ref_ptr<menu_text_layout> rval = new menu_text_layout;
+    cwidget::util::ref_ptr<menu_text_layout> rval = new menu_text_layout;
     rval->decref();
     return rval;
   }
 
-  static ref_ptr<menu_text_layout> create(fragment *f)
+  static cwidget::util::ref_ptr<menu_text_layout> create(cwidget::fragment *f)
   {
-    ref_ptr<menu_text_layout> rval = new menu_text_layout(f);
+    cwidget::util::ref_ptr<menu_text_layout> rval = new menu_text_layout(f);
     rval->decref();
     return rval;
   }
 
-  bool handle_key(const key &k);
+  bool handle_key(const cwidget::config::key &k);
 
   bool find_search_enabled();
   bool find_search();
@@ -80,6 +80,6 @@ public:
   bool find_repeat_search_back_enabled();
   bool find_repeat_search_back();
 };
-typedef ref_ptr<menu_text_layout> menu_text_layout_ref;
+typedef cwidget::util::ref_ptr<menu_text_layout> menu_text_layout_ref;
 
 #endif
