@@ -37,26 +37,36 @@
 
 #include <sigc++/adaptors/bind.h>
 
-vs_editline::history_list menu_tree::search_history;
+namespace cw = cwidget;
+namespace cwidget
+{
+  using namespace widgets;
+}
 
-class pkg_matcher_search:public vs_tree_search_func
+cw::editline::history_list menu_tree::search_history;
+
+class pkg_matcher_search:public cw::tree_search_func
 {
   pkg_matcher *matcher;
 public:
   pkg_matcher_search(pkg_matcher *_matcher):matcher(_matcher) {}
 
-  bool operator()(const vs_treeitem &item)
+  bool operator()(const cw::treeitem &item)
   {
     // EWW
     const pkg_item *pitem=dynamic_cast<const pkg_item *>(&item);
     if(pitem)
-      return matcher->matches(pitem->get_package());
+      return matcher->matches(pitem->get_package(),
+			      *apt_cache_file,
+			      *apt_package_records);
     else {
       const pkg_ver_item *pvitem=dynamic_cast<const pkg_ver_item *>(&item);
 
       if(pvitem)
 	return matcher->matches(pvitem->get_package(),
-				pvitem->get_version());
+				pvitem->get_version(),
+				*apt_cache_file,
+				*apt_package_records);
       else
 	return false;
     }
@@ -81,7 +91,7 @@ bool menu_tree::proxy_redirect(bool (menu_redirect::*call)())
   if(!get_visible())
     return false;
 
-  vs_treeiterator curr = get_selected();
+  cw::treeiterator curr = get_selection();
   if(curr == get_end())
     return false;
 
@@ -201,11 +211,11 @@ bool menu_tree::find_search_enabled()
 
 bool menu_tree::find_search()
 {
-  prompt_string(transcode(_("Search for: ")),
+  prompt_string(W_("Search for: "),
 		last_search_term,
-		arg(sigc::bind(sigc::mem_fun(*this, &menu_tree::do_search), false)),
-		arg(sigc::mem_fun(*this, &menu_tree::do_cancel_incsearch)),
-		arg(sigc::bind(sigc::mem_fun(*this, &menu_tree::do_incsearch), false)),
+		cw::util::arg(sigc::bind(sigc::mem_fun(*this, &menu_tree::do_search), false)),
+		cw::util::arg(sigc::mem_fun(*this, &menu_tree::do_cancel_incsearch)),
+		cw::util::arg(sigc::bind(sigc::mem_fun(*this, &menu_tree::do_incsearch), false)),
 		&search_history);
 
   return true;
@@ -218,11 +228,11 @@ bool menu_tree::find_search_back_enabled()
 
 bool menu_tree::find_search_back()
 {
-  prompt_string(transcode(_("Search backwards for: ")),
+  prompt_string(W_("Search backwards for: "),
 		last_search_term,
-		arg(sigc::bind(sigc::mem_fun(*this, &menu_tree::do_search), true)),
-		arg(sigc::mem_fun(*this, &menu_tree::do_cancel_incsearch)),
-		arg(sigc::bind(sigc::mem_fun(*this, &menu_tree::do_incsearch), true)),
+		cw::util::arg(sigc::bind(sigc::mem_fun(*this, &menu_tree::do_search), true)),
+		cw::util::arg(sigc::mem_fun(*this, &menu_tree::do_cancel_incsearch)),
+		cw::util::arg(sigc::bind(sigc::mem_fun(*this, &menu_tree::do_incsearch), true)),
 		&search_history);
 
   return true;
@@ -319,7 +329,7 @@ void menu_tree::do_search(std::wstring s, bool backward)
     {
       delete last_search_matcher;
       last_search_term=s;
-      last_search_matcher=parse_pattern(transcode(s));
+      last_search_matcher=parse_pattern(cw::util::transcode(s));
     }
 
   if(doing_incsearch)
@@ -349,10 +359,10 @@ void menu_tree::do_incsearch(std::wstring s, bool backward)
   if(!doing_incsearch)
     {
       doing_incsearch=true;
-      pre_incsearch_selected=get_selected();
+      pre_incsearch_selected=get_selection();
     }
 
-  pkg_matcher *m=parse_pattern(transcode(s), false, false);
+  pkg_matcher *m=parse_pattern(cw::util::transcode(s), false, false);
 
   set_selection(pre_incsearch_selected);
 
@@ -384,7 +394,7 @@ void menu_tree::reset_incsearch()
   pre_incsearch_selected=get_end();
 }
 
-bool menu_tree::handle_key(const key &k)
+bool menu_tree::handle_key(const cw::config::key &k)
 {
   // ick -- but having our own bindings is also ugly. hm.
   if(pkg_tree::bindings->key_matches(k, "Search"))
@@ -398,7 +408,7 @@ bool menu_tree::handle_key(const key &k)
   else if(pkg_tree::bindings->key_matches(k, "SearchBroken"))
     find_broken();
   else
-    return vs_tree::handle_key(k);
+    return cw::tree::handle_key(k);
 
   return true;
 }
