@@ -10,22 +10,22 @@
 #include <sigc++/adaptors/bind.h>
 #include <sigc++/functors/mem_fun.h>
 
-#include <vscreen/config/keybindings.h>
-#include <vscreen/config/colors.h>
+#include <cwidget/config/keybindings.h>
+#include <cwidget/config/colors.h>
 
-#include <vscreen/vscreen_widget.h>
-#include <vscreen/vscreen.h>
+#include <cwidget/widgets/widget.h>
+#include <cwidget/toplevel.h>
 
-#include <vscreen/transcode.h>
-#include <vscreen/vs_button.h>
-#include <vscreen/vs_center.h>
-#include <vscreen/vs_editline.h>
-#include <vscreen/vs_frame.h>
-#include <vscreen/vs_label.h>
-#include <vscreen/vs_radiogroup.h>
-#include <vscreen/vs_table.h>
-#include <vscreen/vs_togglebutton.h>
-#include <vscreen/vs_util.h>
+#include <cwidget/generic/util/transcode.h>
+#include <cwidget/widgets/button.h>
+#include <cwidget/widgets/center.h>
+#include <cwidget/widgets/editline.h>
+#include <cwidget/widgets/frame.h>
+#include <cwidget/widgets/label.h>
+#include <cwidget/widgets/radiogroup.h>
+#include <cwidget/widgets/table.h>
+#include <cwidget/widgets/togglebutton.h>
+#include <cwidget/dialogs.h>
 
 #include <string>
 #include <fstream>
@@ -49,10 +49,16 @@
 #endif
 
 using namespace std;
+namespace cw = cwidget;
+namespace dialogs = cwidget::dialogs;
+namespace cwidget
+{
+  using namespace widgets;
+}
 
-keybindings *cmine::bindings;
+cwidget::config::keybindings *cmine::bindings;
 
-vs_editline::history_list cmine::load_history, cmine::save_history;
+cw::editline::history_list cmine::load_history, cmine::save_history;
 
 int cmine::width_request()
 {
@@ -70,9 +76,9 @@ int cmine::height_request(int w)
     return 1;
 }
 
-class cmine::update_header_event : public vscreen_event
+class cmine::update_header_event : public cw::toplevel::event
 {
-  ref_ptr<cmine> cm;
+  cwidget::util::ref_ptr<cmine> cm;
 
 public:
   update_header_event(cmine *_cm)
@@ -88,28 +94,28 @@ public:
 
 void cmine::update_header()
 {
-  timeout_num = vscreen_addtimeout(new update_header_event(this), 500);
+  timeout_num = cw::toplevel::addtimeout(new update_header_event(this), 500);
 
-  vscreen_update();
+  cw::toplevel::update();
 };
 
-void cmine::paint_header(const style &st)
+void cmine::paint_header(const cwidget::style &st)
   // Shows the header with its extra info
 {
-  vs_widget_ref tmpref(this);
+  cw::widget_ref tmpref(this);
 
   if(board)
     {
       int width,height;
       getmaxyx(height,width);
 
-      wstring header=transcode(_("Minesweeper"));
+      wstring header=W_("Minesweeper");
       wchar_t buf[200];
 
       if(board->get_state()==mine_board::playing)
 	swprintf(buf,
 		 sizeof(buf),
-		 transcode(_("%i/%i mines  %d %s")).c_str(),
+		 W_("%i/%i mines  %d %s").c_str(),
 		 board->get_nummines()-board->get_numflags(),
 		 board->get_nummines(),
 		 (int) board->get_duration(),
@@ -117,7 +123,7 @@ void cmine::paint_header(const style &st)
       else
 	swprintf(buf,
 		 sizeof(buf),
-		 transcode(_("    %s in %d %s")).c_str(),
+		 W_("    %s in %d %s").c_str(),
 		 board->get_state()==mine_board::won?_("Won"):_("Lost"),
 		 (int) board->get_duration(),
 		 board->get_duration()==1?_("second"):_("seconds"));
@@ -142,18 +148,18 @@ void cmine::paint_header(const style &st)
 	  ++loc;
 	}
 
-      display_header(header, st+get_style("Header"));
+      display_header(header, st + cw::get_style("Header"));
     }
   else
-    display_header(transcode(_("Minesweeper")),
-		   st+get_style("Header"));
+    display_header(W_("Minesweeper"),
+		   st+cw::get_style("Header"));
 }
 
 void cmine::do_load_game(wstring ws)
 {
-  vs_widget_ref tmpref(this);
+  cw::widget_ref tmpref(this);
 
-  string s=transcode(ws);
+  string s=cw::util::transcode(ws);
 
   if(s!="")
     {
@@ -164,8 +170,8 @@ void cmine::do_load_game(wstring ws)
 
 	  snprintf(buf, 512, _("Could not open file \"%s\""), s.c_str());
 
-	  popup_widget(vs_dialog_ok(transcode(buf), NULL,
-				    get_style("Error")));
+	  popup_widget(dialogs::ok(cw::util::transcode(buf), NULL,
+				   cw::get_style("Error")));
 	}
       else
 	{
@@ -180,14 +186,14 @@ void cmine::do_load_game(wstring ws)
 	      snprintf(buf, 512, _("Could not load game from %s"),
 		       s.c_str());
 
-	      popup_widget(vs_dialog_ok(transcode(buf), NULL,
-					get_style("Error")));
+	      popup_widget(dialogs::ok(cw::util::transcode(buf), NULL,
+				       cw::get_style("Error")));
 	      delete brd;
 	    }
 	  else
 	    {
 	      set_board(brd);
-	      vscreen_update();
+	      cw::toplevel::update();
 	    }
 	}
     }
@@ -195,9 +201,9 @@ void cmine::do_load_game(wstring ws)
 
 void cmine::do_save_game(wstring ws)
 {
-  vs_widget_ref tmpref(this);
+  cw::widget_ref tmpref(this);
 
-  string s=transcode(ws);
+  string s=cw::util::transcode(ws);
 
   if(s!="")
     {
@@ -208,27 +214,27 @@ void cmine::do_save_game(wstring ws)
 
 	  snprintf(buf, 512, _("Could not open file \"%s\""), s.c_str());
 
-	  popup_widget(vs_dialog_ok(transcode(buf), NULL,
-				    get_style("Error")));
+	  popup_widget(dialogs::ok(cw::util::transcode(buf), NULL,
+				   cw::get_style("Error")));
 	}
       else
 	{
 	  board->save(out);
-	  vscreen_update();
+	  cw::toplevel::update();
 	}
     }
 }
 
-void cmine::do_start_custom_game(vscreen_widget &w_bare,
-				 vs_editline &heightedit_bare,
-				 vs_editline &widthedit_bare,
-				 vs_editline &minesedit_bare)
+void cmine::do_start_custom_game(cw::widget &w_bare,
+				 cw::editline &heightedit_bare,
+				 cw::editline &widthedit_bare,
+				 cw::editline &minesedit_bare)
 {
-  vs_widget_ref tmpref(this);
+  cw::widget_ref tmpref(this);
 
   // Be ultra-safe and hold strong references to everything.
-  vs_widget_ref w(&w_bare);
-  vs_editline_ref heightedit(&heightedit_bare),
+  cw::widget_ref w(&w_bare);
+  cw::editline_ref heightedit(&heightedit_bare),
     widthedit(&widthedit_bare), minesedit(&minesedit_bare);
 
   wstring s=heightedit->get_text();
@@ -244,9 +250,9 @@ void cmine::do_start_custom_game(vscreen_widget &w_bare,
       //
       //
       // That's ok, they'll do that anyway in a couple releases ;-)
-      popup_widget(vs_dialog_ok(transcode(_("The board height must be a positive integer")),
-				NULL,
-				get_style("Error")));
+      popup_widget(dialogs::ok(W_("The board height must be a positive integer"),
+			       NULL,
+			       cw::get_style("Error")));
       return;
     }
 
@@ -256,9 +262,9 @@ void cmine::do_start_custom_game(vscreen_widget &w_bare,
 
   if(s.c_str()[0]=='\0' || *end!='\0' || width<1)
     {
-      popup_widget(vs_dialog_ok(transcode(_("The board width must be a positive integer")),
-				NULL,
-				get_style("Error")));
+      popup_widget(dialogs::ok(W_("The board width must be a positive integer"),
+			       NULL,
+			       cw::get_style("Error")));
       return;
     }
 
@@ -268,9 +274,9 @@ void cmine::do_start_custom_game(vscreen_widget &w_bare,
 
   if(s.c_str()[0]=='\0' || *end!='\0' || mines<1)
     {
-      popup_widget(vs_dialog_ok(transcode(_("Invalid mine count; please enter a positive integer")),
-				NULL,
-				get_style("Error")));
+      popup_widget(dialogs::ok(W_("Invalid mine count; please enter a positive integer"),
+			       NULL,
+			       cw::get_style("Error")));
       return;
     }
 
@@ -281,40 +287,40 @@ void cmine::do_start_custom_game(vscreen_widget &w_bare,
 
 void cmine::do_custom_game()
 {
-  vs_widget_ref tmpref(this);
+  cw::widget_ref tmpref(this);
 
-  vs_center_ref center=vs_center::create();
-  center->set_bg_style(style_attrs_flip(A_REVERSE));
+  cw::center_ref center = cw::center::create();
+  center->set_bg_style(cwidget::style_attrs_flip(A_REVERSE));
 
-  vs_table_ref table=vs_table::create();
+  cw::table_ref table = cw::table::create();
 
-  vs_label_ref overalllabel=vs_label::create(_("Setup custom game"));
+  cw::label_ref overalllabel = cw::label::create(_("Setup custom game"));
 
-  vs_label_ref heightlabel=vs_label::create(_("Height of board: "));
-  vs_editline_ref heightedit=vs_editline::create(L"");
+  cw::label_ref heightlabel = cw::label::create(_("Height of board: "));
+  cw::editline_ref heightedit = cw::editline::create(L"");
 
-  vs_label_ref widthlabel=vs_label::create(_("Width of board: "));
-  vs_editline_ref widthedit=vs_editline::create(L"");
+  cw::label_ref widthlabel = cw::label::create(_("Width of board: "));
+  cw::editline_ref widthedit = cw::editline::create(L"");
 
-  vs_label_ref mineslabel=vs_label::create(_("Number of mines: "));
-  vs_editline_ref minesedit=vs_editline::create(L"");
+  cw::label_ref mineslabel = cw::label::create(_("Number of mines: "));
+  cw::editline_ref minesedit = cw::editline::create(L"");
 
-  vs_button_ref okbutton=vs_button::create(_("Ok"));
-  vs_button_ref cancelbutton=vs_button::create(_("Cancel"));
+  cw::button_ref okbutton = cw::button::create(_("Ok"));
+  cw::button_ref cancelbutton = cw::button::create(_("Cancel"));
 
-  table->connect_key("Confirm", &global_bindings, okbutton->pressed.make_slot());
+  table->connect_key("Confirm", &cwidget::config::global_bindings, okbutton->pressed.make_slot());
 
   okbutton->pressed.connect(sigc::bind(sigc::mem_fun(*this, &cmine::do_start_custom_game),
 				       center.weak_ref(),
 				       heightedit.weak_ref(),
 				       widthedit.weak_ref(),
 				       minesedit.weak_ref()));
-  cancelbutton->pressed.connect(sigc::mem_fun(*center.unsafe_get_ref(), &vscreen_widget::destroy));
+  cancelbutton->pressed.connect(sigc::mem_fun(*center.unsafe_get_ref(), &cw::widget::destroy));
 
-  table->connect_key("Cancel", &global_bindings, cancelbutton->pressed.make_slot());
+  table->connect_key("Cancel", &cwidget::config::global_bindings, cancelbutton->pressed.make_slot());
 
-  vs_center_ref cyes=vs_center::create(okbutton);
-  vs_center_ref cno=vs_center::create(cancelbutton);
+  cw::center_ref cyes = cw::center::create(okbutton);
+  cw::center_ref cno = cw::center::create(cancelbutton);
 
   table->add_widget(overalllabel, 0, 0, 1, 2, true, false);
 
@@ -342,7 +348,7 @@ void cmine::do_custom_game()
   cyes->show();
   cno->show();
 
-  vs_frame_ref frame=vs_frame::create(table);
+  cw::frame_ref frame = cw::frame::create(table);
   center->add_widget(frame);
 
   popup_widget(center);
@@ -350,31 +356,31 @@ void cmine::do_custom_game()
 
 void cmine::do_new_game()
 {
-  vs_widget_ref tmpref(this);
+  cw::widget_ref tmpref(this);
 
-  vs_center_ref center=vs_center::create();
-  center->set_bg_style(style_attrs_flip(A_REVERSE));
+  cw::center_ref center = cw::center::create();
+  center->set_bg_style(cwidget::style_attrs_flip(A_REVERSE));
 
-  vs_table_ref table=vs_table::create();
+  cw::table_ref table = cw::table::create();
 
-  vs_label_ref overalllabel=vs_label::create(_("Choose difficulty level"));
+  cw::label_ref overalllabel = cw::label::create(_("Choose difficulty level"));
 
-  vs_radiobutton_ref easybutton=vs_radiobutton::create(_("Easy"), true);
-  vs_radiobutton_ref mediumbutton=vs_radiobutton::create(_("Medium"), false);
-  vs_radiobutton_ref hardbutton=vs_radiobutton::create(_("Hard"), false);
-  vs_radiobutton_ref custombutton=vs_radiobutton::create(_("Custom"), false);
+  cw::radiobutton_ref easybutton = cw::radiobutton::create(_("Easy"), true);
+  cw::radiobutton_ref mediumbutton = cw::radiobutton::create(_("Medium"), false);
+  cw::radiobutton_ref hardbutton = cw::radiobutton::create(_("Hard"), false);
+  cw::radiobutton_ref custombutton = cw::radiobutton::create(_("Custom"), false);
 
-  vs_button_ref okbutton=vs_button::create(_("Ok"));
-  vs_button_ref cancelbutton=vs_button::create(_("Cancel"));
+  cw::button_ref okbutton = cw::button::create(_("Ok"));
+  cw::button_ref cancelbutton = cw::button::create(_("Cancel"));
 
-  table->connect_key_post("Confirm", &global_bindings, okbutton->pressed.make_slot());
+  table->connect_key_post("Confirm", &cw::config::global_bindings, okbutton->pressed.make_slot());
 
-  easybutton->connect_key("Confirm", &global_bindings, okbutton->pressed.make_slot());
-  mediumbutton->connect_key("Confirm", &global_bindings, okbutton->pressed.make_slot());
-  hardbutton->connect_key("Confirm", &global_bindings, okbutton->pressed.make_slot());
-  custombutton->connect_key("Confirm", &global_bindings, okbutton->pressed.make_slot());
+  easybutton->connect_key("Confirm", &cw::config::global_bindings, okbutton->pressed.make_slot());
+  mediumbutton->connect_key("Confirm", &cw::config::global_bindings, okbutton->pressed.make_slot());
+  hardbutton->connect_key("Confirm", &cw::config::global_bindings, okbutton->pressed.make_slot());
+  custombutton->connect_key("Confirm", &cw::config::global_bindings, okbutton->pressed.make_slot());
 
-  vs_radiogroup *grp=new vs_radiogroup;
+  cw::radiogroup *grp = new cw::radiogroup;
   grp->add_button(easybutton, 0);
   grp->add_button(mediumbutton, 1);
   grp->add_button(hardbutton, 2);
@@ -389,8 +395,8 @@ void cmine::do_new_game()
 					   center.weak_ref(),
 					   grp));
 
-  vs_center_ref cok=vs_center::create(okbutton);
-  vs_center_ref ccancel=vs_center::create(cancelbutton);
+  cw::center_ref cok = cw::center::create(okbutton);
+  cw::center_ref ccancel = cw::center::create(cancelbutton);
 
   table->add_widget(overalllabel, 0, 0, 1, 2, true, false);
   table->add_widget(easybutton,   1, 0, 1, 2, true, false);
@@ -400,19 +406,19 @@ void cmine::do_new_game()
   table->add_widget(cok,          6, 0, 1, 1, false, false);
   table->add_widget(ccancel,      6, 1, 1, 1, false, false);
 
-  vs_frame_ref frame=vs_frame::create(table);
+  cw::frame_ref frame = cw::frame::create(table);
   center->add_widget(frame);
 
   popup_widget(center);
 }
 
 void cmine::do_continue_new_game(bool start,
-				 vscreen_widget &w_bare,
-				 vs_radiogroup *grp)
+				 cw::widget &w_bare,
+				 cw::radiogroup *grp)
 {
-  vs_widget_ref tmpref(this);
+  cw::widget_ref tmpref(this);
 
-  vs_widget_ref w(&w_bare);
+  cw::widget_ref w(&w_bare);
 
   if(start)
     switch(grp->get_selected())
@@ -430,9 +436,9 @@ void cmine::do_continue_new_game(bool start,
 	do_custom_game();
 	break;
       default:
-	popup_widget(vs_dialog_ok(transcode("Internal error: execution reached an impossible point"),
-				  NULL,
-				  get_style("Error")));
+	popup_widget(dialogs::ok(cw::util::transcode("Internal error: execution reached an impossible point"),
+				 NULL,
+				 cw::get_style("Error")));
 	break;
       }
 
@@ -443,26 +449,32 @@ void cmine::do_continue_new_game(bool start,
 cmine::cmine():board(NULL), prevwidth(0), prevheight(0)
 {
   set_board(easy_game());
-  vscreen_addtimeout(new update_header_event(this), 500);
+  cw::toplevel::addtimeout(new update_header_event(this), 500);
   //set_status(_("n - New Game  Cursor keys - move cursor  f - flag  enter - check  ? - help"));
 }
 
+cmine::~cmine()
+{
+  delete board;
+  cw::toplevel::deltimeout(timeout_num);
+}
+
 void cmine::checkend()
   // Prints out silly messages when the player wins or loses
 {
-  vs_widget_ref tmpref(this);
+  cw::widget_ref tmpref(this);
 
   if(board->get_state()==mine_board::won)
     // "You hold up the Amulet of Yendor.  An invisible choir sings..."
-    popup_widget(vs_dialog_ok(transcode(_("You have won."))));
+    popup_widget(dialogs::ok(W_("You have won.")));
   else if(board->get_state()==mine_board::lost)
     {
-      popup_widget(vs_dialog_ok(transcode(_("You lose!"))));
+      popup_widget(dialogs::ok(W_("You lose!")));
 #if 0
       // (messages in reverse order because the minibuf is a stack by default..
       // I could use the special feature of sticking them at the end, but I
       // want them to override whatever's there (probably nothing :) )
-      add_status_widget(new vs_label(_("You die...  --More--"),
+      add_status_widget(new cw::label(_("You die...  --More--"),
 				     retr_status_color()));
       switch(rand()/(RAND_MAX/8))
 	{
@@ -475,35 +487,35 @@ void cmine::checkend()
 	      if(rand()<(RAND_MAX/3))
 		{
 		  if(rand()<(RAND_MAX/2))
-		    add_status_widget(vs_label::create(_("The spikes were poisoned!  The poison was deadly...  --More--"),
+		    add_status_widget(cw::label::create(_("The spikes were poisoned!  The poison was deadly...  --More--"),
 						       retr_status_color()));
 
-		  add_status_widget(vs_label::create(_("You land on a set of sharp iron spikes!  --More--"),
+		  add_status_widget(cw::label::create(_("You land on a set of sharp iron spikes!  --More--"),
 						     retr_status_color()));
 		}
-	      add_status_widget(vs_label::create(_("You fall into a pit!  --More--"),
+	      add_status_widget(cw::label::create(_("You fall into a pit!  --More--"),
 						 retr_status_color()));
 	    }
-	  add_status_widget(vs_label::create(_("KABOOM!  You step on a land mine.  --More--"),
+	  add_status_widget(cw::label::create(_("KABOOM!  You step on a land mine.  --More--"),
 					     retr_status_color()));
 	  break;
 	case 4:
 	  if(rand()<RAND_MAX/2)
-	    add_status_widget(vs_label::create(_("The dart was poisoned!  The poison was deadly...  --More--"),
+	    add_status_widget(cw::label::create(_("The dart was poisoned!  The poison was deadly...  --More--"),
 					       retr_status_color()));
-	  add_status_widget(vs_label::create(_("A little dart shoots out at you!  You are hit by a little dart!  --More--"),
+	  add_status_widget(cw::label::create(_("A little dart shoots out at you!  You are hit by a little dart!  --More--"),
 					     retr_status_color()));
 	  break;
 	case 5:
-	  add_status_widget(vs_label::create(_("You turn to stone... --More--"),
+	  add_status_widget(cw::label::create(_("You turn to stone... --More--"),
 					     retr_status_color()));
-	  add_status_widget(vs_label::create(_("Touching the cockatrice corpse was a fatal mistake.  --More--"),
+	  add_status_widget(cw::label::create(_("Touching the cockatrice corpse was a fatal mistake.  --More--"),
 					     retr_status_color()));
-	  add_status_widget(vs_label::create(_("You feel here a cockatrice corpse.  --More--"),
+	  add_status_widget(cw::label::create(_("You feel here a cockatrice corpse.  --More--"),
 					     retr_status_color()));
 	  break;
 	case 6:
-	  add_status_widget(vs_label::create(_("Click!  You trigger a rolling boulder trap!  You are hit by a boulder! --More--"),
+	  add_status_widget(cw::label::create(_("Click!  You trigger a rolling boulder trap!  You are hit by a boulder! --More--"),
 					     retr_status_color()));
 	  break;
 	case 7:
@@ -542,11 +554,11 @@ void cmine::checkend()
 
 	      snprintf(buf, 512, _("Your wand of %s breaks apart and explodes!  --More--"));
 
-	      add_status_widget(vs_label::create(buf,
+	      add_status_widget(cw::label::create(buf,
 						 retr_status_color()));
 	    }
 
-	  add_status_widget(vs_label::create(_("You are jolted by a surge of electricity!  --More--"),
+	  add_status_widget(cw::label::create(_("You are jolted by a surge of electricity!  --More--"),
 					     retr_status_color()));
 	  break;
 	}
@@ -568,12 +580,12 @@ void cmine::set_board(mine_board *_board)
   basex=(width-_board->get_width()-2)/2;
   basey=(height-_board->get_height()-4)/2;
 
-  vscreen_update();
+  cw::toplevel::update();
 }
 
-bool cmine::handle_key(const key &k)
+bool cmine::handle_key(const cwidget::config::key &k)
 {
-  vs_widget_ref tmpref(this);
+  cw::widget_ref tmpref(this);
 
   int width,height;
   getmaxyx(height, width);
@@ -589,23 +601,23 @@ bool cmine::handle_key(const key &k)
 
 	  checkend();
 	}
-      vscreen_update();
+      cw::toplevel::update();
     }
   else if(bindings->key_matches(k, "MineUncoverSquare"))
     {
       board->uncover(curx, cury);
-      vscreen_update();
+      cw::toplevel::update();
     }
   else if(bindings->key_matches(k, "MineSweepSquare"))
     {
       board->sweep(curx, cury);
-      vscreen_update();
+      cw::toplevel::update();
     }
   else if(bindings->key_matches(k, "MineFlagSquare"))
     {
       board->toggle_flag(curx, cury);
       // FIXME: handle errors?
-      vscreen_update();
+      cw::toplevel::update();
     }
   else if(bindings->key_matches(k, "Up"))
     {
@@ -614,7 +626,7 @@ bool cmine::handle_key(const key &k)
 	  cury--;
 	  while(basey+cury+1<1)
 	    basey++;
-	  vscreen_update();
+	  cw::toplevel::update();
 	}
     }
   else if(bindings->key_matches(k, "Down"))
@@ -624,7 +636,7 @@ bool cmine::handle_key(const key &k)
 	  cury++;
 	  while(basey+cury+1>=height-3)
 	    basey--;
-	  vscreen_update();
+	  cw::toplevel::update();
 	}
     }
   else if(bindings->key_matches(k, "Left"))
@@ -634,7 +646,7 @@ bool cmine::handle_key(const key &k)
 	  curx--;
 	  while(basex+curx+1<1)
 	    basex++;
-	  vscreen_update();
+	  cw::toplevel::update();
 	}
     }
   else if(bindings->key_matches(k, "Right"))
@@ -644,7 +656,7 @@ bool cmine::handle_key(const key &k)
 	  curx++;
 	  while(basex+curx+1>=width-1)
 	    basex--;
-	  vscreen_update();
+	  cw::toplevel::update();
 	}
     }
   else if(bindings->key_matches(k, "MineNewGame"))
@@ -652,14 +664,14 @@ bool cmine::handle_key(const key &k)
   else if(bindings->key_matches(k, "MineLoadGame"))
     prompt_string(_("Enter the filename to load: "),
 		  "",
-		  arg(sigc::mem_fun(*this, &cmine::do_load_game)),
+		  cw::util::arg(sigc::mem_fun(*this, &cmine::do_load_game)),
 		  NULL,
 		  NULL,
 		  &load_history);
   else if(bindings->key_matches(k, "MineSaveGame"))
     prompt_string(_("Enter the filename to save: "),
 		  "",
-		  arg(sigc::mem_fun(*this, &cmine::do_save_game)),
+		  cw::util::arg(sigc::mem_fun(*this, &cmine::do_save_game)),
 		  NULL,
 		  NULL,
 		  &save_history);
@@ -677,7 +689,7 @@ bool cmine::handle_key(const key &k)
 	  encoding="UTF-8";
 	}
 
-      vs_widget_ref w=vs_dialog_fileview(buf, NULL, NULL, NULL, NULL, encoding);
+      cw::widget_ref w = dialogs::fileview(buf, NULL, NULL, NULL, NULL, encoding);
       w->show_all();
 
       popup_widget(w);
@@ -688,7 +700,7 @@ bool cmine::handle_key(const key &k)
   return true;
 }
 
-void cmine::paint_square(int x, int y, const style &st)
+void cmine::paint_square(int x, int y, const cwidget::style &st)
   // Displays a single square.
 {
   int width,height;
@@ -702,7 +714,7 @@ void cmine::paint_square(int x, int y, const style &st)
   if(screenx>=0 && screenx<width && screeny>=0 && screeny<height-1)
     {
       wchar_t ch;
-      style cur_st;
+      cwidget::style cur_st;
       const mine_board::board_entry &entry=board->get_square(x, y);
       // We want to handle the case of 'game-over' differently from
       // the case of 'still playing' -- when the game is over, all
@@ -714,18 +726,18 @@ void cmine::paint_square(int x, int y, const style &st)
 	      if(entry.flagged)
 		{
 		  ch=L'F';
-		  cur_st=get_style("MineFlag");
+		  cur_st=cw::get_style("MineFlag");
 		}
 	      else
 		{
 		  ch=L' ';
-		  cur_st=get_style("DefaultWidgetBackground");
+		  cur_st=cw::get_style("DefaultWidgetBackground");
 		}
 	    }
 	  else if(entry.contains_mine)
 	    {
 	      ch=L'^';
-	      cur_st=get_style("MineBombColor");
+	      cur_st=cw::get_style("MineBombColor");
 	    }
 	  else if(entry.adjacent_mines==0)
 	    ch=L'.';
@@ -734,7 +746,7 @@ void cmine::paint_square(int x, int y, const style &st)
 	      ch=(L'0'+entry.adjacent_mines);
 	      string stname("MineNumber");
 	      stname+=(char) '0'+entry.adjacent_mines;
-	      cur_st=get_style(string("MineNumber")+char('0'+entry.adjacent_mines));
+	      cur_st=cw::get_style(string("MineNumber")+char('0'+entry.adjacent_mines));
 	    }
 	}
       else
@@ -745,12 +757,12 @@ void cmine::paint_square(int x, int y, const style &st)
 		 x==board->get_minex() && y==board->get_miney())
 		{
 		  ch=L'*';
-		  cur_st=get_style("MineDetonated");
+		  cur_st=cw::get_style("MineDetonated");
 		}
 	      else
 		{
 		  ch=L'^';
-		  cur_st=get_style("MineBomb");
+		  cur_st=cw::get_style("MineBomb");
 		}
 	    }
 	  else if(entry.uncovered || true)
@@ -762,21 +774,21 @@ void cmine::paint_square(int x, int y, const style &st)
 		  ch=(L'0'+entry.adjacent_mines);
 		  string stname("MineNumber");
 		  stname+=(char) '0'+entry.adjacent_mines;
-		  cur_st=get_style(string("MineNumber")+char('0'+entry.adjacent_mines));
+		  cur_st=cw::get_style(string("MineNumber")+char('0'+entry.adjacent_mines));
 		}
 	    }
 	  else
 	    ch=L' ';
 	}
       if(board->get_state()==mine_board::playing && x==curx && y==cury)
-	cur_st+=style_attrs_flip(A_REVERSE);
+	cur_st+=cwidget::style_attrs_flip(A_REVERSE);
 
       apply_style(cur_st);
       mvadd_wch(screeny, screenx, ch);
     }
 }
 
-void cmine::paint(const style &st)
+void cmine::paint(const cwidget::style &st)
 {
   if(get_win())
     {
@@ -807,7 +819,7 @@ void cmine::paint(const style &st)
 
       if(board)
 	{
-	  apply_style(st+get_style("MineBorder"));
+	  apply_style(st+cw::get_style("MineBorder"));
 
 	  int right=basex+board->get_width()+1, down=basey+1+board->get_height()+1;
 	  // x and y coordinates, respectively, of the right and lower
@@ -913,24 +925,24 @@ void cmine::init_bindings()
 {
   srand(time(0));
 
-  set_style("MineFlag", style_fg(COLOR_RED)+style_attrs_on(A_BOLD));
-  set_style("MineBomb", style_fg(COLOR_RED)+style_attrs_on(A_BOLD));
-  set_style("MineDetonated", style_fg(COLOR_RED)+style_attrs_on(A_BOLD));
-  set_style("MineNumber1", style_fg(COLOR_WHITE));
-  set_style("MineNumber2", style_fg(COLOR_GREEN));
-  set_style("MineNumber3", style_fg(COLOR_CYAN));
-  set_style("MineNumber4", style_fg(COLOR_MAGENTA)+style_attrs_on(A_BOLD));
-  set_style("MineNumber5", style_fg(COLOR_RED)+style_attrs_on(A_BOLD));
-  set_style("MineNumber6", style_attrs_on(A_BOLD)+style_fg(COLOR_CYAN));
-  set_style("MineNumber7", style_attrs_on(A_BOLD)+style_fg(COLOR_GREEN));
-  set_style("MineNumber8", style_attrs_on(A_BOLD));
-  set_style("MineBorder", style_attrs_on(A_BOLD));
+  cw::set_style("MineFlag", cw::style_fg(COLOR_RED)+cw::style_attrs_on(A_BOLD));
+  cw::set_style("MineBomb", cw::style_fg(COLOR_RED)+cw::style_attrs_on(A_BOLD));
+  cw::set_style("MineDetonated", cw::style_fg(COLOR_RED)+cw::style_attrs_on(A_BOLD));
+  cw::set_style("MineNumber1", cw::style_fg(COLOR_WHITE));
+  cw::set_style("MineNumber2", cw::style_fg(COLOR_GREEN));
+  cw::set_style("MineNumber3", cw::style_fg(COLOR_CYAN));
+  cw::set_style("MineNumber4", cw::style_fg(COLOR_MAGENTA)+cw::style_attrs_on(A_BOLD));
+  cw::set_style("MineNumber5", cw::style_fg(COLOR_RED)+cw::style_attrs_on(A_BOLD));
+  cw::set_style("MineNumber6", cw::style_attrs_on(A_BOLD)+cw::style_fg(COLOR_CYAN));
+  cw::set_style("MineNumber7", cw::style_attrs_on(A_BOLD)+cw::style_fg(COLOR_GREEN));
+  cw::set_style("MineNumber8", cw::style_attrs_on(A_BOLD));
+  cw::set_style("MineBorder", cw::style_attrs_on(A_BOLD));
 
-  global_bindings.set("MineUncoverSweepSquare", key(KEY_ENTER, true));
-  global_bindings.set("MineFlagSquare", key(L'f', false));
-  global_bindings.set("MineNewGame", key(L'n', false));
-  global_bindings.set("MineSaveGame", key(L'S', false));
-  global_bindings.set("MineLoadGame", key(L'L', false));
+  cw::config::global_bindings.set("MineUncoverSweepSquare", cw::config::key(KEY_ENTER, true));
+  cw::config::global_bindings.set("MineFlagSquare", cw::config::key(L'f', false));
+  cw::config::global_bindings.set("MineNewGame", cw::config::key(L'n', false));
+  cw::config::global_bindings.set("MineSaveGame", cw::config::key(L'S', false));
+  cw::config::global_bindings.set("MineLoadGame", cw::config::key(L'L', false));
 
-  bindings=new keybindings(&global_bindings);
+  bindings = new cw::config::keybindings(&cw::config::global_bindings);
 }
