@@ -1,6 +1,6 @@
 // pkg_info_screen.cc
 //
-//  Copyright 2000-2002, 2004-2005 Daniel Burrows
+//  Copyright 2000-2002, 2004-2005, 2007 Daniel Burrows
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -25,8 +25,8 @@
 
 #include "pkg_info_screen.h"
 
-#include "vscreen/fragment.h"
-#include "vscreen/vs_layout_item.h"
+#include <cwidget/fragment.h>
+#include <cwidget/widgets/layout_item.h>
 
 #include "dep_item.h"
 #include "desc_parse.h"
@@ -40,6 +40,12 @@
 #include <apt-pkg/pkgrecords.h>
 #include <apt-pkg/strutl.h>
 
+namespace cw = cwidget;
+namespace cwidget
+{
+  using namespace widgets;
+}
+
 class pkg_grouppolicy_info:public pkg_grouppolicy
 {
 public:
@@ -78,35 +84,41 @@ void pkg_grouppolicy_info::setup_package_info(const pkgCache::PkgIterator &pkg,
     {
       pkgRecords::Parser &rec=apt_package_records->Lookup(ver.FileList());
 
-      std::wstring desc(get_long_description(ver));
+      std::wstring desc(get_long_description(ver, apt_package_records));
       std::wstring shortdesc(desc, 0, desc.find(L'\n'));
 
-      vector<fragment*> frags;
+      vector<cw::fragment*> frags;
 
-      fragment *untrusted_warning=make_untrusted_warning(ver);
+      cw::fragment *untrusted_warning=make_untrusted_warning(ver);
       if(untrusted_warning != NULL)
 	{
 	  frags.push_back(untrusted_warning);
-	  frags.push_back(newline_fragment());
+	  frags.push_back(cw::newline_fragment());
 	}
 
       // Avoid creating new strings to translate.
-      frags.push_back(clipbox(fragf("%B%s%b%ls%n",
+      frags.push_back(clipbox(cw::fragf("%B%s%b%ls%n",
 				    _("Description: "), shortdesc.c_str())));
       frags.push_back(indentbox(2, 2, make_desc_fragment(desc)));
 
-      fragment *tags = make_tags_fragment(pkg);
+#ifdef APT_HAS_HOMEPAGE
+      if(rec.Homepage() != "")
+	frags.push_back(cw::dropbox(cw::fragf("%B%s%b", _("Homepage: ")),
+				cw::hardwrapbox(cw::text_fragment(rec.Homepage()))));
+#endif
+
+      cw::fragment *tags = make_tags_fragment(pkg);
       if(tags != NULL)
-	frags.push_back(fragf("%n%F", tags));
+	frags.push_back(cw::fragf("%n%F", tags));
 
       // Can I use something other than a clipbox below?
 
       if((pkg->Flags&pkgCache::Flag::Essential)==pkgCache::Flag::Essential ||
 	 (pkg->Flags&pkgCache::Flag::Important)==pkgCache::Flag::Important)
-	frags.push_back(clipbox(fragf("%B%s%b%s",
+	frags.push_back(clipbox(cw::fragf("%B%s%b%s",
 				      _("Essential: "), _("yes"))));
 
-      frags.push_back(clipbox(fragf("%B%s%b%s%n"
+      frags.push_back(clipbox(cw::fragf("%B%s%b%s%n"
 				    "%B%s%b%s%n"
 				    "%B%s%b%s%n"
 				    "%B%s%b%s%n"
@@ -120,7 +132,7 @@ void pkg_grouppolicy_info::setup_package_info(const pkgCache::PkgIterator &pkg,
 				    _("Source Package: "),
 				    rec.SourcePkg().empty()?pkg.Name():rec.SourcePkg().c_str())));
 
-      tree->add_child(new vs_layout_item(sequence_fragment(frags)));
+      tree->add_child(new cw::layout_item(cw::sequence_fragment(frags)));
 
       setup_package_deps<pkg_item_with_generic_subtree>(pkg, ver, tree, sig);
 
@@ -128,7 +140,7 @@ void pkg_grouppolicy_info::setup_package_info(const pkgCache::PkgIterator &pkg,
       if(!ver.ProvidesList().end())
 	{
 	  snprintf(buf, 256, _("Package names provided by %s"), pkg.Name());
-	  pkg_subtree *prvtree=new pkg_subtree(transcode(buf));
+	  pkg_subtree *prvtree=new pkg_subtree(cw::util::transcode(buf));
 
 	  for(pkgCache::PrvIterator prv=ver.ProvidesList(); !prv.end(); ++prv)
 	    prvtree->add_child(new pkg_item(prv.ParentPkg(), sig));
@@ -138,11 +150,11 @@ void pkg_grouppolicy_info::setup_package_info(const pkgCache::PkgIterator &pkg,
     }
 
   snprintf(buf, 256, _("Packages which depend on %s"), pkg.Name());
-  pkg_subtree *revtree=new pkg_subtree(transcode(buf));
+  pkg_subtree *revtree=new pkg_subtree(cw::util::transcode(buf));
   setup_package_deps<pkg_subtree>(pkg, ver, revtree, sig, true);
   tree->add_child(revtree);
 
-  pkg_vertree_generic *newtree=new pkg_vertree_generic(transcode(_("Versions")), true);
+  pkg_vertree_generic *newtree=new pkg_vertree_generic(W_("Versions"), true);
   setup_package_versions(pkg, newtree, sig);
   tree->add_child(newtree);
 }
@@ -154,7 +166,7 @@ pkg_info_screen::pkg_info_screen(const pkgCache::PkgIterator &pkg,
   set_root(setup_new_root(pkg, ver), true);
 }
 
-vs_treeitem *pkg_info_screen::setup_new_root(const pkgCache::PkgIterator &pkg,
+cw::treeitem *pkg_info_screen::setup_new_root(const pkgCache::PkgIterator &pkg,
 					     const pkgCache::VerIterator &ver)
 {
   pkg_item_with_generic_subtree *tree=new pkg_item_with_generic_subtree(pkg,
