@@ -24,7 +24,13 @@
 #include <apt-pkg/pkgsystem.h>
 #include <apt-pkg/version.h>
 
-#include <vscreen/vs_subtree.h>
+#include <cwidget/widgets/subtree.h>
+
+namespace cw = cwidget;
+namespace cwidget
+{
+  using namespace widgets;
+}
 
 // Blah, this is the easiest way to define trivial subclasses:
 // (not that far from lambda, actually)
@@ -69,7 +75,7 @@ pkg_sortpolicy *name(pkg_sortpolicy *chain, bool reversed)	\
  *  \return \b true if the conversion was successful.
  */
 static
-bool find_package_and_ver(vs_treeitem *item,
+bool find_package_and_ver(cw::treeitem *item,
 			  pkgCache::PkgIterator &pkg,
 			  pkgCache::VerIterator &ver)
 {
@@ -92,8 +98,8 @@ bool find_package_and_ver(vs_treeitem *item,
   return false;
 }
 
-int pkg_sortpolicy_wrapper::compare(vs_treeitem *item1,
-				    vs_treeitem *item2) const
+int pkg_sortpolicy_wrapper::compare(cw::treeitem *item1,
+				    cw::treeitem *item2) const
 {
   pkgCache::PkgIterator pkg1, pkg2;
   pkgCache::VerIterator ver1, ver2;
