@@ -1,6 +1,6 @@
 // pkg_subtree.h (this is -*-c++-*-)
 //
-//  Copyright 1999-2002, 2004-2005 Daniel Burrows
+//  Copyright 1999-2002, 2004-2005, 2007 Daniel Burrows
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -22,35 +22,40 @@
 #ifndef PKG_SUBTREE_H
 #define PKG_SUBTREE_H
 
-#include "vscreen/vs_subtree.h"
+#include <cwidget/widgets/subtree.h>
 
 #include "pkg_node.h"
 
-class pkg_subtree:public vs_subtree<pkg_tree_node>,
+class pkg_subtree:public cwidget::widgets::subtree<pkg_tree_node>,
 		  public pkg_tree_node
 {
   std::wstring name;
   std::wstring description; // This is like a Description: field.
 
   sigc::signal1<void, std::wstring> *info_signal;
+
+  void do_highlighted_changed(bool highlighted);
 protected:
   void set_label(const std::wstring &_name) {name=_name;}
 public:
   pkg_subtree(std::wstring _name, std::wstring _description=L"",
 	      sigc::signal1<void, std::wstring> *_info_signal=NULL,
 	      bool _expanded=false):
-    vs_subtree<pkg_tree_node>(_expanded), name(_name),
+    cwidget::widgets::subtree<pkg_tree_node>(_expanded), name(_name),
     description(_description), info_signal(_info_signal)
-  {}
-
-  pkg_subtree(std::wstring _name, bool _expanded):
-    vs_subtree<pkg_tree_node>(_expanded), name(_name),
-    description(L""), info_signal(NULL)
   {
+    highlighted_changed.connect(sigc::mem_fun(this, &pkg_subtree::do_highlighted_changed));
   }
 
-  virtual void paint(vs_tree *win, int y, bool hierarchical,
-		     const style &st);
+  pkg_subtree(std::wstring _name, bool _expanded):
+    cwidget::widgets::subtree<pkg_tree_node>(_expanded), name(_name),
+    description(L""), info_signal(NULL)
+  {
+    highlighted_changed.connect(sigc::mem_fun(this, &pkg_subtree::do_highlighted_changed));
+  }
+
+  virtual void paint(cwidget::widgets::tree *win, int y, bool hierarchical,
+		     const cwidget::style &st);
   virtual const wchar_t *tag();
   virtual const wchar_t *label();
 
@@ -62,13 +67,10 @@ public:
   virtual void reinstall(undo_group *undo);
   virtual void set_auto(bool isauto, undo_group *undo);
 
-  virtual void highlighted(vs_tree *win);
-  virtual void unhighlighted(vs_tree *win);
-
   std::wstring get_name() {return name;}
   std::wstring get_description() {return description;}
 
-  bool dispatch_key(const key &k, vs_tree *owner);
+  bool dispatch_key(const cwidget::config::key &k, cwidget::widgets::tree *owner);
 };
 
 #endif
