@@ -1,6 +1,6 @@
 // pkg_tree.cc
 //
-//  Copyright 1999-2005 Daniel Burrows
+//  Copyright 1999-2005, 2007 Daniel Burrows
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -30,11 +30,12 @@
 #include "pkg_sortpolicy.h"
 #include "pkg_subtree.h"
 #include "ui.h"
-#include "vs_progress.h"
+#include "progress.h"
 
-#include <vscreen/columnify.h>
-#include <vscreen/transcode.h>
-#include <vscreen/vs_treeitem.h>
+#include <cwidget/columnify.h>
+#include <cwidget/generic/util/transcode.h>
+#include <cwidget/toplevel.h>
+#include <cwidget/widgets/treeitem.h>
 
 #include <generic/apt/apt.h>
 #include <generic/apt/config_signal.h>
@@ -47,14 +48,20 @@
 #include <sigc++/adaptors/retype_return.h>
 #include <sigc++/functors/mem_fun.h>
 
-keybindings *pkg_tree::bindings=NULL;
+namespace cw = cwidget;
+namespace cwidget
+{
+  using namespace widgets;
+}
 
-vs_editline::history_list pkg_tree::limit_history, pkg_tree::grouping_history,
+cw::config::keybindings *pkg_tree::bindings=NULL;
+
+cw::editline::history_list pkg_tree::limit_history, pkg_tree::grouping_history,
   pkg_tree::sorting_history;
 
 void pkg_tree::init_bindings()
 {
-  bindings=new keybindings(vs_tree::bindings);
+  bindings=new cw::config::keybindings(cw::tree::bindings);
 }
 
 pkg_tree::pkg_tree(const std::string &def_grouping,
@@ -68,7 +75,7 @@ pkg_tree::pkg_tree(const std::string &def_grouping,
    limitstr(def_limit)
 {
   if(!limitstr.empty())
-    limit=parse_pattern(transcode(limitstr));
+    limit=parse_pattern(cw::util::transcode(limitstr));
 }
 
 pkg_tree::pkg_tree(const std::string &def_grouping,
@@ -78,10 +85,10 @@ pkg_tree::pkg_tree(const std::string &def_grouping,
    sorting(parse_sortpolicy(aptcfg->Find(PACKAGE "::UI::Default-Sorting",
 					 "name"))),
    limit(NULL),
-   limitstr(transcode(aptcfg->Find(PACKAGE "::Pkg-Display-Limit", "")))
+   limitstr(cw::util::transcode(aptcfg->Find(PACKAGE "::Pkg-Display-Limit", "")))
 {
   if(!limitstr.empty())
-    limit=parse_pattern(transcode(limitstr));
+    limit=parse_pattern(cw::util::transcode(limitstr));
 }
 
 void pkg_tree::handle_cache_close()
@@ -112,7 +119,7 @@ void pkg_tree::set_grouping(pkg_grouppolicy_factory *_grouping)
 void pkg_tree::set_grouping(const std::wstring &s)
 {
   // FIXME: push wstrings down into the parsing code.
-  groupingstr=transcode(s);
+  groupingstr=cw::util::transcode(s);
 
   pkg_grouppolicy_factory *grp=parse_grouppolicy(groupingstr);
 
@@ -134,7 +141,7 @@ void pkg_tree::set_sorting(pkg_sortpolicy *_sorting)
 void pkg_tree::set_sorting(const std::wstring &s)
 {
   // FIXME: push wstrings down into the parsing code.
-  pkg_sortpolicy *policy=parse_sortpolicy(transcode(s));
+  pkg_sortpolicy *policy=parse_sortpolicy(cw::util::transcode(s));
 
   if(policy)
     set_sorting(policy);
@@ -163,7 +170,7 @@ bool pkg_tree::build_tree(OpProgress &progress)
     {
       bool empty=true, cache_empty=true;
 
-      pkg_subtree *mytree=new pkg_subtree(transcode(_("All Packages")), true);
+      pkg_subtree *mytree=new pkg_subtree(W_("All Packages"), true);
       pkg_grouppolicy *grouper=grouping->instantiate(&selected_signal,
 						     &selected_desc_signal);
 
@@ -184,7 +191,7 @@ bool pkg_tree::build_tree(OpProgress &progress)
 	  if(i.VersionList().end() && i.ProvidesList().end())
 	    continue;
 
-	  if((!limit) || limit->matches(i))
+	  if((!limit) || limit->matches(i, *apt_cache_file, *apt_package_records))
 	    {
 	      empty=false;
 	      grouper->add_package(i, mytree);
@@ -205,14 +212,14 @@ bool pkg_tree::build_tree(OpProgress &progress)
   else
     rval=true;
 
-  vscreen_update();
+  cw::toplevel::update();
 
   return rval;
 }
 
 bool pkg_tree::build_tree()
 {
-  vs_progress_ref p=gen_progress_bar();
+  progress_ref p=gen_progress_bar();
   bool rval=build_tree(*p.unsafe_get_ref());
   p->destroy();
 
@@ -224,7 +231,7 @@ void pkg_tree::set_limit(const std::wstring &_limit)
   pkg_matcher *old_limit=limit;
   std::wstring old_limitstr=limitstr;
 
-  pkg_matcher *new_limit=parse_pattern(transcode(_limit));
+  pkg_matcher *new_limit=parse_pattern(cw::util::transcode(_limit));
   if(_limit.empty() || new_limit)
     {
       limit=new_limit;
@@ -234,7 +241,7 @@ void pkg_tree::set_limit(const std::wstring &_limit)
 	{
 	  wchar_t buf[512];
 
-	  swprintf(buf, 512, transcode(_("No packages matched the pattern \"%ls\".")).c_str(),
+	  swprintf(buf, 512, W_("No packages matched the pattern \"%ls\".").c_str(),
 		   _limit.c_str());
 
 	  show_message(buf);
@@ -256,9 +263,9 @@ bool pkg_tree::find_limit_enabled()
 
 bool pkg_tree::find_limit()
 {
-  prompt_string(transcode(_("Enter the new package tree limit: ")),
+  prompt_string(W_("Enter the new package tree limit: "),
 		limitstr,
-		arg(sigc::mem_fun(*this, &pkg_tree::set_limit)),
+		cw::util::arg(sigc::mem_fun(*this, &pkg_tree::set_limit)),
 		NULL,
 		NULL,
 		&limit_history);
@@ -285,14 +292,14 @@ bool pkg_tree::find_reset_limit()
   return true;
 }
 
-bool pkg_tree::handle_key(const key &k)
+bool pkg_tree::handle_key(const cw::config::key &k)
 {
   if(bindings->key_matches(k, "ChangePkgTreeLimit"))
     find_limit();
   else if(bindings->key_matches(k, "ChangePkgTreeGrouping"))
     prompt_string(_("Enter the new package grouping mechanism for this display: "),
 		  groupingstr,
-		  arg(sigc::mem_fun(*this,
+		  cw::util::arg(sigc::mem_fun(*this,
 				    (void (pkg_tree::*) (const std::wstring &)) &pkg_tree::set_grouping)),
 		  NULL,
 		  NULL,
@@ -300,7 +307,7 @@ bool pkg_tree::handle_key(const key &k)
   else if(bindings->key_matches(k, "ChangePkgTreeSorting"))
     prompt_string(_("Enter the new package sorting mechanism for this display: "),
 		  "",
-		  arg(sigc::mem_fun(*this,
+		  cw::util::arg(sigc::mem_fun(*this,
 				    (void (pkg_tree::*) (const std::wstring &)) &pkg_tree::set_sorting)),
 		  NULL,
 		  NULL,
