@@ -30,13 +30,14 @@
 #include "pkg_sortpolicy.h"
 #include "ui.h"
 #include "view_changelog.h"
-#include "vs_progress.h"
+#include "progress.h"
 
 #include <generic/apt/apt.h>
 #include <generic/apt/apt_undo_group.h>
 #include <generic/apt/config_signal.h>
 
-#include "vscreen/vs_multiplex.h"
+#include <cwidget/toplevel.h>
+#include <cwidget/widgets/multiplex.h>
 
 #include <algorithm>
 #include <string>
@@ -50,25 +51,31 @@
 
 using namespace std;
 
-column_disposition pkg_ver_columnizer::setup_column(int type)
+namespace cw = cwidget;
+namespace cwidget
+{
+  using namespace widgets;
+}
+
+cw::column_disposition pkg_ver_columnizer::setup_column(int type)
 {
   return setup_column(get_visible_ver(), show_pkg_name, get_basex(), type);
 }
 
-column_disposition pkg_ver_columnizer::setup_column(const pkgCache::VerIterator &ver,
-						    bool show_pkg_name,
-						    int basex,
-						    int type)
+cw::column_disposition pkg_ver_columnizer::setup_column(const pkgCache::VerIterator &ver,
+							bool show_pkg_name,
+							int basex,
+							int type)
 {
   switch(type)
     {
     case name:
       if(ver.end())
-	return column_disposition("", 0);
+	return cw::column_disposition("", 0);
       else if(show_pkg_name)
-	return column_disposition(string(ver.ParentPkg().Name())+" "+ver.VerStr(), basex);
+	return cw::column_disposition(string(ver.ParentPkg().Name())+" "+ver.VerStr(), basex);
       else
-	return column_disposition(ver.VerStr(), basex);
+	return cw::column_disposition(ver.VerStr(), basex);
 
       break;
 
@@ -82,16 +89,16 @@ column_disposition pkg_ver_columnizer::setup_column(const pkgCache::VerIterator
 	      if(pkgfile.Archive() && strcmp(pkgfile.Archive(), "now"))
 		buf+=string(buf.empty()?"":",")+pkgfile.Archive();
 	    }
-	  return column_disposition(buf,0);
+	  return cw::column_disposition(buf,0);
 	}
 
     case installed_size:
       if(ver.end())
-	return column_disposition("", 0);
+	return cw::column_disposition("", 0);
       else if(ver->InstalledSize>0)
-	return column_disposition(SizeToStr(ver->InstalledSize)+'B', 0);
+	return cw::column_disposition(SizeToStr(ver->InstalledSize)+'B', 0);
       else
-	return column_disposition(_("<N/A>"), 0);
+	return cw::column_disposition(_("<N/A>"), 0);
 
       break;
 
@@ -104,12 +111,12 @@ column_disposition pkg_ver_columnizer::setup_column(const pkgCache::VerIterator
 	    pkgPolicy *policy=dynamic_cast<pkgPolicy *>(&(*apt_cache_file)->GetPolicy());
 
 	    if(!policy)
-	      return column_disposition("", 0);
+	      return cw::column_disposition("", 0);
 
 	    pkgCache::VerFileIterator vf=ver.FileList();
 
 	    if(vf.end())
-	      return column_disposition("", 0);
+	      return cw::column_disposition("", 0);
 
 	    signed short priority=policy->GetPriority(vf.File());
 
@@ -124,15 +131,15 @@ column_disposition pkg_ver_columnizer::setup_column(const pkgCache::VerIterator
 
 	    snprintf(buf, 256, "%d", priority);
 
-	    return column_disposition(buf, 0);
+	    return cw::column_disposition(buf, 0);
 	  }
 	else
-	  return column_disposition("", 0);
+	  return cw::column_disposition("", 0);
       }
 
     case sizechange:
       if(ver.end())
-	return column_disposition("", 0);
+	return cw::column_disposition("", 0);
 
       {
 	pkgCache::PkgIterator pkg=ver.ParentPkg();
@@ -142,95 +149,101 @@ column_disposition pkg_ver_columnizer::setup_column(const pkgCache::VerIterator
 
 	if((ver==curver && ver==instver) ||
 	   (ver!=curver && ver!=instver))
-	  return column_disposition("", 0);
+	  return cw::column_disposition("", 0);
 	else if(ver==curver)
-	  return column_disposition("-"+SizeToStr(ver->InstalledSize)+"B", 0);
+	  return cw::column_disposition("-"+SizeToStr(ver->InstalledSize)+"B", 0);
 	else
-	  return column_disposition("+"+SizeToStr(ver->InstalledSize)+"B", 0);
+	  return cw::column_disposition("+"+SizeToStr(ver->InstalledSize)+"B", 0);
       }
 
       break;
     case debsize:
       if(ver.end())
-	return column_disposition("", 0);
+	return cw::column_disposition("", 0);
       else if(ver->Size>0)
-	return column_disposition(SizeToStr(ver->Size)+'B', 0);
+	return cw::column_disposition(SizeToStr(ver->Size)+'B', 0);
       else
-	return column_disposition(_("<N/A>"), 0);
+	return cw::column_disposition(_("<N/A>"), 0);
       break;
     case currver:
-      return column_disposition("", 0);
+      return cw::column_disposition("", 0);
     case candver:
-      return column_disposition("", 0);
+      return cw::column_disposition("", 0);
     case stateflag:
       // Can't be virtual since we have a bona fide version
       if(ver.end())
-	return column_disposition("", 0);
+	return cw::column_disposition("", 0);
 
       if(ver.ParentPkg().CurrentVer()!=ver)
-	return column_disposition("p", 0);
+	return cw::column_disposition("p", 0);
 
       if((*apt_cache_file)[ver.ParentPkg()].NowBroken())
-	return column_disposition("B", 0);
+	return cw::column_disposition("B", 0);
 
       switch(ver.ParentPkg()->CurrentState)
 	{
 	case pkgCache::State::NotInstalled:
-	  return column_disposition("p", 0);
+	  return cw::column_disposition("p", 0);
 	  // Assume it's purged if we're in this state.  Is this correct?
 	  // If it's removed but config-files are present it should be
 	  // in the ConfigFiles state.
 	case pkgCache::State::UnPacked:
-	  return column_disposition("u", 0);
+	  return cw::column_disposition("u", 0);
 	case pkgCache::State::HalfConfigured:
-	  return column_disposition("C", 0);
+	  return cw::column_disposition("C", 0);
 	case pkgCache::State::HalfInstalled:
-	  return column_disposition("H", 0);
+	  return cw::column_disposition("H", 0);
 	case pkgCache::State::ConfigFiles:
-	  return column_disposition("c", 0);
+	  return cw::column_disposition("c", 0);
 	case pkgCache::State::Installed:
-	  return column_disposition("i", 0);
+	  return cw::column_disposition("i", 0);
+#ifdef APT_HAS_TRIGGERS
+	case pkgCache::State::TriggersAwaited:
+	  return cw::column_disposition("W", 0);
+	case pkgCache::State::TriggersPending:
+	  return cw::column_disposition("T", 0);
+#endif
 	default:
-	  return column_disposition("E", 0);
+	  return cw::column_disposition("E", 0);
 	}
 
       break;
     case longstate:
       if(ver.end())
-	return column_disposition("", 0);
+	return cw::column_disposition("", 0);
 
       if(ver.ParentPkg().CurrentVer()!=ver)
-	return column_disposition(_("purged"), 0);
+	return cw::column_disposition(_("purged"), 0);
 
       if((*apt_cache_file)[ver.ParentPkg()].NowBroken())
-	return column_disposition(_("broken"), 0);
+	return cw::column_disposition(_("broken"), 0);
 
       switch(ver.ParentPkg()->CurrentState)
 	{
 	case pkgCache::State::NotInstalled:
-	  return column_disposition(_("purged"), 0);
+	  return cw::column_disposition(_("purged"), 0);
 	  // Assume it's purged if we're in this state.  Is this correct?
 	  // If it's removed but config-files are present it should be
 	  // in the ConfigFiles state.
 	case pkgCache::State::UnPacked:
-	  return column_disposition(_("unpacked"), 0);
+	  return cw::column_disposition(_("unpacked"), 0);
 	case pkgCache::State::HalfConfigured:
-	  return column_disposition(_("half-config"), 0);
+	  return cw::column_disposition(_("half-config"), 0);
 	case pkgCache::State::HalfInstalled:
-	  return column_disposition(_("half-install"), 0);
+	  return cw::column_disposition(_("half-install"), 0);
 	case pkgCache::State::ConfigFiles:
-	  return column_disposition(_("config-files"), 0);
+	  return cw::column_disposition(_("config-files"), 0);
 	case pkgCache::State::Installed:
-	  return column_disposition(_("installed"), 0);
+	  return cw::column_disposition(_("installed"), 0);
 	default:
-	  return column_disposition(_("ERROR"), 0);
+	  return cw::column_disposition(_("ERROR"), 0);
 	}
 
       break;
     case actionflag:
       {
 	if(ver.end())
-	  return column_disposition("", 0);
+	  return cw::column_disposition("", 0);
 
 	pkgCache::PkgIterator pkg=ver.ParentPkg();
 	aptitudeDepCache::StateCache &state=(*apt_cache_file)[pkg];
@@ -238,140 +251,140 @@ column_disposition pkg_ver_columnizer::setup_column(const pkgCache::VerIterator
 	pkgCache::VerIterator candver=state.CandidateVerIter(*apt_cache_file);
 
 	if(state.Status!=2 && estate.selection_state==pkgCache::State::Hold && !state.NowBroken())
-	  return column_disposition("h", 0);
+	  return cw::column_disposition("h", 0);
 	else if(ver.VerStr() == estate.forbidver)
-	  return column_disposition("F", 0);
+	  return cw::column_disposition("F", 0);
 	else if(state.Delete())
-	  return column_disposition((state.iFlags&pkgDepCache::Purge)?"p":"d", 0);
+	  return cw::column_disposition((state.iFlags&pkgDepCache::Purge)?"p":"d", 0);
 	else if(state.InstBroken() && state.InstVerIter(*apt_cache_file)==ver)
-	  return column_disposition("B", 0);
+	  return cw::column_disposition("B", 0);
 	else if(state.NewInstall())
 	  {
 	    if(candver==ver)
-	      return column_disposition("i", 0);
+	      return cw::column_disposition("i", 0);
 	    else
-	      return column_disposition(" ", 0);
+	      return cw::column_disposition(" ", 0);
 	  }
 	else if(state.iFlags&pkgDepCache::ReInstall)
 	  {
 	    if(ver.ParentPkg().CurrentVer()==ver)
-	      return column_disposition("i", 0);
+	      return cw::column_disposition("i", 0);
 	    else
-	      return column_disposition(" ", 0);
+	      return cw::column_disposition(" ", 0);
 	  }
 	else if(state.Upgrade())
 	  {
 	    if(ver.ParentPkg().CurrentVer()==ver)
-	      return column_disposition("d", 0);
+	      return cw::column_disposition("d", 0);
 	    else if(candver==ver)
-	      return column_disposition("i", 0);
+	      return cw::column_disposition("i", 0);
 	    else
-	      return column_disposition(" ", 0);
+	      return cw::column_disposition(" ", 0);
 	  }
 	else
-	  return column_disposition(" ", 0);
+	  return cw::column_disposition(" ", 0);
       }
 
       break;
     case longaction:
       {
 	if(ver.end())
-	  return column_disposition("", 0);
+	  return cw::column_disposition("", 0);
 
 	aptitudeDepCache::StateCache state=(*apt_cache_file)[ver.ParentPkg()];
 	aptitudeDepCache::aptitude_state &estate=(*apt_cache_file)->get_ext_state(ver.ParentPkg());
 	if(state.Status!=2 && (state.Held() || estate.selection_state==pkgCache::State::Hold) && !state.NowBroken())
-	  return column_disposition(_("hold"), 0);
+	  return cw::column_disposition(_("hold"), 0);
 	else if(ver.VerStr() == estate.forbidver)
-	  return column_disposition("forbidden version", 0);
+	  return cw::column_disposition("forbidden version", 0);
 	else if(state.Delete())
-	  return column_disposition((state.iFlags&pkgDepCache::Purge)?"p":"d", 0);
+	  return cw::column_disposition((state.iFlags&pkgDepCache::Purge)?"p":"d", 0);
 	else if(state.InstBroken() && state.InstVerIter(*apt_cache_file)==ver)
-	  return column_disposition(_("broken"), 0);
+	  return cw::column_disposition(_("broken"), 0);
 	else if(state.NewInstall())
 	  {
 	    if(state.CandidateVerIter(*apt_cache_file)==ver)
-	      return column_disposition(_("install"), 0);
+	      return cw::column_disposition(_("install"), 0);
 	    else
-	      return column_disposition(_("none"), 0);
+	      return cw::column_disposition(_("none"), 0);
 	  }
 	else if(state.iFlags&pkgDepCache::ReInstall)
 	  {
 	    if(ver.ParentPkg().CurrentVer()==ver)
-	      return column_disposition(_("install"), 0);
+	      return cw::column_disposition(_("install"), 0);
 	    else
-	      return column_disposition(_("none"), 0);
+	      return cw::column_disposition(_("none"), 0);
 	  }
 	else if(state.Upgrade())
 	  {
 	    if(ver.ParentPkg().CurrentVer()==ver)
-	      return column_disposition(_("delete"), 0);
+	      return cw::column_disposition(_("delete"), 0);
 	    else if((*apt_cache_file)[ver.ParentPkg()].CandidateVerIter(*apt_cache_file)==ver)
-	      return column_disposition(_("install"), 0);
+	      return cw::column_disposition(_("install"), 0);
 	    else
-	      return column_disposition(_("none"), 0);
+	      return cw::column_disposition(_("none"), 0);
 	  }
 	else
-	  return column_disposition(_("none"), 0);
+	  return cw::column_disposition(_("none"), 0);
       }
 
       break;
     case description:
-      return column_disposition(get_short_description(ver), 0);
+      return cw::column_disposition(get_short_description(ver, apt_package_records), 0);
     case maintainer:
       if(ver.end())
-	return column_disposition("", 0);
+	return cw::column_disposition("", 0);
 
-      return column_disposition(apt_package_records->Lookup(ver.FileList()).Maintainer(), 0);
+      return cw::column_disposition(apt_package_records->Lookup(ver.FileList()).Maintainer(), 0);
     case priority:
       if(ver.end())
-	return column_disposition("", 0);
+	return cw::column_disposition("", 0);
 
       if(const_cast<pkgCache::VerIterator &>(ver).PriorityType() &&
 	 const_cast<pkgCache::VerIterator &>(ver).PriorityType()[0])
-	return column_disposition(const_cast<pkgCache::VerIterator &>(ver).PriorityType(), 0);
+	return cw::column_disposition(const_cast<pkgCache::VerIterator &>(ver).PriorityType(), 0);
       else
-	return column_disposition(_("Unknown"), 0);
+	return cw::column_disposition(_("Unknown"), 0);
     case shortpriority:
       if(ver.end())
-	return column_disposition("", 0);
+	return cw::column_disposition("", 0);
 
       switch(ver->Priority)
 	{
 	case pkgCache::State::Important:
 	  // ForTranslators: Imp = Important
-	  return column_disposition(_("Imp"), 0);
+	  return cw::column_disposition(_("Imp"), 0);
 	case pkgCache::State::Required:
 	  // ForTranslators: Req = Required
-	  return column_disposition(_("Req"), 0);
+	  return cw::column_disposition(_("Req"), 0);
 	case pkgCache::State::Standard:
 	  // ForTranslators: Std = Standard
-	  return column_disposition(_("Std"), 0);
+	  return cw::column_disposition(_("Std"), 0);
 	case pkgCache::State::Optional:
 	  // ForTranslators: Opt = Optional
-	  return column_disposition(_("Opt"), 0);
+	  return cw::column_disposition(_("Opt"), 0);
 	case pkgCache::State::Extra:
 	  // ForTranslators: Xtr = Extra
-	  return column_disposition(_("Xtr"), 0);
+	  return cw::column_disposition(_("Xtr"), 0);
 	default:
-	  return column_disposition(_("ERR"), 0);
+	  return cw::column_disposition(_("ERR"), 0);
 	}
 
       break;
     case section:
       if(ver.end())
-	return column_disposition("", 0);
+	return cw::column_disposition("", 0);
 
       if(ver.Section())
-	return column_disposition(ver.Section(), 0);
+	return cw::column_disposition(ver.Section(), 0);
       else
-	return column_disposition(_("Unknown"), 0);
+	return cw::column_disposition(_("Unknown"), 0);
 
       break;
     case revdepcount:
       {
 	if(ver.end())
-	  return column_disposition("", 0);
+	  return cw::column_disposition("", 0);
 
 	int count=0;
 	char buf[100];
@@ -395,16 +408,16 @@ column_disposition pkg_ver_columnizer::setup_column(const pkgCache::VerIterator
 	      }
 	  }
 	snprintf(buf, 100, "%i", count);
-	return column_disposition(buf, 0);
+	return cw::column_disposition(buf, 0);
       }
     case trust_state:
       {
 	if(ver.end())
-	  return column_disposition(" ", 0);
+	  return cw::column_disposition(" ", 0);
 	else if(package_trusted(ver))
-	  return column_disposition(" ", 0);
+	  return cw::column_disposition(" ", 0);
 	else
-	  return column_disposition("U", 0);
+	  return cw::column_disposition("U", 0);
       }
     default:
       return pkg_columnizer::setup_column(ver.ParentPkg(),
@@ -465,26 +478,27 @@ pkg_grouppolicy *pkg_grouppolicy_ver_factory::instantiate(pkg_signal *sig,
   return new pkg_grouppolicy_ver(sig, desc_sig);
 }
 
-style pkg_ver_item::get_normal_style()
+cw::style pkg_ver_item::get_normal_style()
 {
-  return vs_treeitem::get_normal_style() + ver_style(version, false);
+  return cw::treeitem::get_normal_style() + ver_style(version, false);
 }
 
-style pkg_ver_item::get_highlighted_style()
+cw::style pkg_ver_item::get_highlighted_style()
 {
-  return vs_treeitem::get_normal_style() + ver_style(version, true);
+  return cw::treeitem::get_normal_style() + ver_style(version, true);
 }
 
 pkg_ver_item::pkg_ver_item(const pkgCache::VerIterator &_version, pkg_signal *_sig,
 			   bool _show_pkg_name)
-  :version(_version), version_name(transcode(version.VerStr(), "ASCII")),
+  :version(_version), version_name(cw::util::transcode(version.VerStr(), "ASCII")),
    show_pkg_name(_show_pkg_name), sig(_sig)
 {
+  highlighted_changed.connect(sigc::mem_fun(this, &pkg_ver_item::do_highlighted_changed));
 }
 
 #define MAYBE_HIGHLIGHTED(x) (highlighted ? (x "Highlighted") : (x))
 
-style pkg_ver_item::ver_style(pkgCache::VerIterator version,
+cw::style pkg_ver_item::ver_style(pkgCache::VerIterator version,
 			      bool highlighted)
 {
   pkgCache::PkgIterator pkg=version.ParentPkg();
@@ -495,30 +509,30 @@ style pkg_ver_item::ver_style(pkgCache::VerIterator version,
       (state.Install() &&
        !state.InstBroken() &&
        state.InstVerIter(*apt_cache_file)!=version)))
-    return get_style(MAYBE_HIGHLIGHTED("PkgToRemove"));
+    return cw::get_style(MAYBE_HIGHLIGHTED("PkgToRemove"));
 
   else if(((state.NewInstall() || state.Install()) &&
 	   !state.InstBroken() &&
 	   state.InstVerIter(*apt_cache_file)==version) ||
 	  (version==version.ParentPkg().CurrentVer() &&
 	   state.iFlags&pkgDepCache::ReInstall))
-    return get_style(MAYBE_HIGHLIGHTED("PkgToInstall"));
+    return cw::get_style(MAYBE_HIGHLIGHTED("PkgToInstall"));
 
   else if(state.InstBroken() && state.InstVerIter(*apt_cache_file)==version)
-    return get_style(MAYBE_HIGHLIGHTED("PkgBroken"));
+    return cw::get_style(MAYBE_HIGHLIGHTED("PkgBroken"));
 
   else if(pkg.CurrentVer()!=version)
-    return get_style(MAYBE_HIGHLIGHTED("PkgNotInstalled"));
+    return cw::get_style(MAYBE_HIGHLIGHTED("PkgNotInstalled"));
 
   else if(state.NowBroken())
-    return get_style(MAYBE_HIGHLIGHTED("PkgBroken"));
+    return cw::get_style(MAYBE_HIGHLIGHTED("PkgBroken"));
 
   else
-    return get_style(MAYBE_HIGHLIGHTED("PkgIsInstalled"));
+    return cw::get_style(MAYBE_HIGHLIGHTED("PkgIsInstalled"));
 }
 
-void pkg_ver_item::paint(vs_tree *win, int y, bool hierarchical,
-			 const style &st)
+void pkg_ver_item::paint(cw::tree *win, int y, bool hierarchical,
+			 const cw::style &st)
 {
   int basex=hierarchical?2*get_depth():0;
   int width, height;
@@ -526,7 +540,7 @@ void pkg_ver_item::paint(vs_tree *win, int y, bool hierarchical,
   win->getmaxyx(height, width);
   pkg_item::pkg_columnizer::setup_columns();
 
-  empty_column_parameters p;
+  cw::config::empty_column_parameters p;
   wstring disp=pkg_ver_columnizer(version,
 				  show_pkg_name,
 				  pkg_item::pkg_columnizer::get_columns(),
@@ -534,17 +548,19 @@ void pkg_ver_item::paint(vs_tree *win, int y, bool hierarchical,
   win->mvaddnstr(y, 0, disp.c_str(), width);
 }
 
-void pkg_ver_item::highlighted(vs_tree *win)
+void pkg_ver_item::do_highlighted_changed(bool highlighted)
 {
-  if(sig)
-    (*sig)(version.ParentPkg(), version);
-}
-
-void pkg_ver_item::unhighlighted(vs_tree *win)
-{
-  if(sig)
-    (*sig)(pkgCache::PkgIterator(),
-	   pkgCache::VerIterator(*apt_cache_file));
+  if(highlighted)
+    {
+      if(sig)
+	(*sig)(version.ParentPkg(), version);
+    }
+  else
+    {
+      if(sig)
+	(*sig)(pkgCache::PkgIterator(),
+	       pkgCache::VerIterator(*apt_cache_file));
+    }
 }
 
 const wchar_t *pkg_ver_item::tag()
@@ -641,7 +657,7 @@ void pkg_ver_item::forbid_version(undo_group *undo)
 
 void pkg_ver_item::show_information()
 {
-  vs_widget_ref w=make_info_screen(version.ParentPkg(), version);
+  cw::widget_ref w=make_info_screen(version.ParentPkg(), version);
 
   char buf[512];
   snprintf(buf, 512, _("Information about %s"), version.ParentPkg().Name());
@@ -659,7 +675,7 @@ pkg_ver_screen::pkg_ver_screen(const pkgCache::PkgIterator &pkg)
   //set_header(_("Available versions of ")+string(pkg.Name()));
 }
 
-vs_treeitem *pkg_ver_screen::setup_new_root(const pkgCache::PkgIterator &pkg,
+cw::treeitem *pkg_ver_screen::setup_new_root(const pkgCache::PkgIterator &pkg,
 					    const pkgCache::VerIterator &ver)
 {
   pkg_vertree *newtree=new pkg_vertree(pkg, get_sig(), true);
@@ -669,7 +685,7 @@ vs_treeitem *pkg_ver_screen::setup_new_root(const pkgCache::PkgIterator &pkg,
   return newtree;
 }
 
-bool pkg_ver_item::dispatch_key(const key &k, vs_tree *owner)
+bool pkg_ver_item::dispatch_key(const cw::config::key &k, cw::tree *owner)
 {
   if(bindings->key_matches(k, "Dependencies"))
     {
@@ -679,7 +695,7 @@ bool pkg_ver_item::dispatch_key(const key &k, vs_tree *owner)
       snprintf(buf, 512, _("%s deps"), version.ParentPkg().Name());
       string tablabel(buf);
 
-      vs_widget_ref w=make_dep_screen(version.ParentPkg(), version);
+      cw::widget_ref w=make_dep_screen(version.ParentPkg(), version);
       insert_main_widget(w, menulabel, "", tablabel);
       return true;
     }
@@ -691,7 +707,7 @@ bool pkg_ver_item::dispatch_key(const key &k, vs_tree *owner)
       snprintf(buf, 512, _("%s reverse deps"), version.ParentPkg().Name());
       string tablabel(buf);
 
-      vs_widget_ref w=make_dep_screen(version.ParentPkg(), version, true);
+      cw::widget_ref w=make_dep_screen(version.ParentPkg(), version, true);
       insert_main_widget(w, menulabel, "", tablabel);
       return true;
     }
@@ -732,7 +748,7 @@ bool pkg_ver_item::dispatch_key(const key &k, vs_tree *owner)
 
       sigaction(SIGCONT, &act, &oldact);
 
-      vscreen_suspend();
+      cw::toplevel::suspend();
 
       apt_cache_file->ReleaseLock();
 
@@ -747,9 +763,9 @@ bool pkg_ver_item::dispatch_key(const key &k, vs_tree *owner)
 
 
 
-      vscreen_resume();
+      cw::toplevel::resume();
 
-      vs_progress_ref p = gen_progress_bar();
+      progress_ref p = gen_progress_bar();
       apt_reload_cache(p.unsafe_get_ref(), true);
       p->destroy();
 
