@@ -31,15 +31,16 @@
 
 #include <cmdline/cmdline_why.h>
 
-#include <vscreen/fragment.h>
-#include <vscreen/vs_label.h>
-#include <vscreen/vs_multiplex.h>
-#include <vscreen/vs_scrollbar.h>
-#include <vscreen/vs_table.h>
-#include <vscreen/vs_text_layout.h>
-#include <vscreen/vscreen_widget.h>
-#include <vscreen/config/keybindings.h>
-#include <vscreen/transcode.h>
+#include <cwidget/config/keybindings.h>
+#include <cwidget/fragment.h>
+#include <cwidget/generic/util/transcode.h>
+#include <cwidget/toplevel.h>
+#include <cwidget/widgets/label.h>
+#include <cwidget/widgets/multiplex.h>
+#include <cwidget/widgets/scrollbar.h>
+#include <cwidget/widgets/table.h>
+#include <cwidget/widgets/text_layout.h>
+#include <cwidget/widgets/widget.h>
 
 #include <generic/apt/apt.h>
 #include <generic/apt/config_signal.h>
@@ -58,9 +59,15 @@
 
 using namespace std;
 
-class pkg_handling_label:public vs_label
+namespace cw = cwidget;
+namespace cwidget
 {
-  column_definition_list *columns;
+  using namespace widgets;
+}
+
+class pkg_handling_label:public cw::label
+{
+  cw::config::column_definition_list *columns;
 
   bool have_pkg;
   pkgCache::PkgIterator pkg;
@@ -72,30 +79,30 @@ class pkg_handling_label:public vs_label
   }
 
 protected:
-  pkg_handling_label(column_definition_list *_columns)
-    :vs_label(" "), columns(_columns), have_pkg(false)
+  pkg_handling_label(cw::config::column_definition_list *_columns)
+    :cw::label(" "), columns(_columns), have_pkg(false)
   {
     cache_closed.connect(sigc::mem_fun(*this, &pkg_handling_label::zap_package));
   }
 
 public:
-  static ref_ptr<pkg_handling_label>
-  create(column_definition_list *columns)
+  static cw::util::ref_ptr<pkg_handling_label>
+  create(cw::config::column_definition_list *columns)
   {
-    ref_ptr<pkg_handling_label> rval(new pkg_handling_label(columns));
+    cw::util::ref_ptr<pkg_handling_label> rval(new pkg_handling_label(columns));
     rval->decref();
     return rval;
   }
 
   ~pkg_handling_label() {delete columns;}
 
-  size size_request() {return size(1,1);}
+  cw::size size_request() {return cw::size(1,1);}
 
-  void set_columns(column_definition_list *_columns)
+  void set_columns(cw::config::column_definition_list *_columns)
   {
     delete columns;
     columns=_columns;
-    vscreen_update();
+    cw::toplevel::update();
   }
 
   void do_columnify(const pkgCache::PkgIterator &_pkg,
@@ -106,12 +113,12 @@ public:
 
     have_pkg=!pkg.end();
 
-    vscreen_update();
+    cw::toplevel::update();
   }
 
-  void paint(const style &st)
+  void paint(const cw::style &st)
   {
-    vs_widget_ref tmpref(this);
+    cw::widget_ref tmpref(this);
 
     if(apt_cache_file)
       {
@@ -126,17 +133,17 @@ public:
 	    ver=pkgCache::VerIterator(*apt_cache_file);
 	  }
 
-	empty_column_parameters p;
+	cw::config::empty_column_parameters p;
 	set_text(pkg_item::pkg_columnizer(pkg, ver, *columns, 0).layout_columns(getmaxx(), p));
       }
     else
       set_text("");
 
-    vs_label::paint(st);
+    cw::label::paint(st);
   }
 };
 
-typedef ref_ptr<pkg_handling_label> pkg_handling_label_ref;
+typedef cw::util::ref_ptr<pkg_handling_label> pkg_handling_label_ref;
 
 static void do_set_column_format(string key, string the_default,
 				 pkg_handling_label &lBare)
@@ -146,10 +153,10 @@ static void do_set_column_format(string key, string the_default,
   string format=aptcfg->Find(key, the_default.c_str());
   wstring wformat;
 
-  column_definition_list *columns=NULL;
+  cw::config::column_definition_list *columns=NULL;
 
-  if(!transcode(format.c_str(), wformat))
-    _error->Errno("iconv", _("Couldn't transcode column definition"));
+  if(!cw::util::transcode(format.c_str(), wformat))
+    _error->Errno("iconv", _("Couldn't cw::util::transcode column definition"));
   else
     columns=parse_columns(wformat,
 			  pkg_item::pkg_columnizer::parse_column_type,
@@ -161,16 +168,16 @@ static void do_set_column_format(string key, string the_default,
     l->set_columns(columns);
 }
 
-class pkg_why_widget:public vs_text_layout
+class pkg_why_widget:public cw::text_layout
 {
 protected:
   pkg_why_widget()
   {
   }
 public:
-  static ref_ptr<pkg_why_widget> create()
+  static cw::util::ref_ptr<pkg_why_widget> create()
   {
-    ref_ptr<pkg_why_widget> rval(new pkg_why_widget);
+    cw::util::ref_ptr<pkg_why_widget> rval(new pkg_why_widget);
     rval->decref();
     return rval;
   }
@@ -180,7 +187,7 @@ public:
   {
     if(pkg.end())
       {
-	set_fragment(text_fragment(""));
+	set_fragment(cw::text_fragment(""));
 	return;
       }
 
@@ -207,18 +214,18 @@ public:
       delete *it;
   }
 };
-typedef ref_ptr<pkg_why_widget> pkg_why_widget_ref;
+typedef cw::util::ref_ptr<pkg_why_widget> pkg_why_widget_ref;
 
-class pkg_description_widget:public vs_text_layout
+class pkg_description_widget:public cw::text_layout
 {
 protected:
   pkg_description_widget()
   {
   }
 public:
-  static ref_ptr<pkg_description_widget> create()
+  static cw::util::ref_ptr<pkg_description_widget> create()
   {
-    ref_ptr<pkg_description_widget> rval(new pkg_description_widget);
+    cw::util::ref_ptr<pkg_description_widget> rval(new pkg_description_widget);
     rval->decref();
     return rval;
   }
@@ -228,17 +235,34 @@ public:
   {
     // Check against pkg.end() to hack around #339533; if ver is a
     // default iterator, pkg.end() is true.
-    wstring newdesc(pkg.end() ? L"" : get_long_description(ver));
+    wstring newdesc(pkg.end() ? L"" : get_long_description(ver, apt_package_records));
 
-    fragment *frag=make_desc_fragment(newdesc);
+    cw::fragment *frag=make_desc_fragment(newdesc);
 
-    fragment *tags=make_tags_fragment(pkg);
-    if(tags != NULL)
-      tags = fragf("%n%n%F", tags);
+#ifdef APT_HAS_HOMEPAGE
+    cw::fragment *homepage;
+    if(!ver.end())
+      {
+	pkgRecords::Parser &rec=apt_package_records->Lookup(ver.FileList());
+	string homepagestr = rec.Homepage();
+	homepage = (homepagestr == ""
+		    ? cw::fragf("")
+		    : cw::dropbox(cw::fragf("%B%s%b", _("Homepage: ")),
+			      cw::hardwrapbox(cw::text_fragment(rec.Homepage()))));
+      }
     else
-      tags = fragf("");
+      homepage = cw::fragf("");
+#else
+    cw::fragment *homepage = cw::fragf("");
+#endif
 
-    fragment *untrusted_frag;
+    cw::fragment *tags=make_tags_fragment(pkg);
+    if(tags != NULL)
+      tags = cw::fragf("%n%n%F", tags);
+    else
+      tags = cw::fragf("");
+
+    cw::fragment *untrusted_frag;
 
     if(pkg.end() || ver.end())
       untrusted_frag=NULL;
@@ -246,13 +270,14 @@ public:
       untrusted_frag=make_untrusted_warning(ver);
 
     if(untrusted_frag == NULL)
-      set_fragment(fragf("%F%F", frag, tags));
+      set_fragment(cw::fragf("%F%F%F", frag, homepage, tags));
     else
-      set_fragment(fragf("%F%n%F%F", untrusted_frag, frag, tags));
+      set_fragment(cw::fragf("%F%n%F%F%F", untrusted_frag, frag,
+			 homepage, tags));
   }
 };
 
-typedef ref_ptr<pkg_description_widget> pkg_description_widget_ref;
+typedef cw::util::ref_ptr<pkg_description_widget> pkg_description_widget_ref;
 
 // In order to properly dispatch line-up/down events to the sub-widgets,
 // we need a meta-widget that knows about them.
@@ -264,17 +289,17 @@ typedef ref_ptr<pkg_description_widget> pkg_description_widget_ref;
 //     of a few redundant pointers is acceptable.  In my opinion.
 //
 // This is still rather gross, and a better way would be nice.
-class info_area_multiplex:public vs_multiplex
+class info_area_multiplex:public cw::multiplex
 {
-  vs_hier_editor_ref editor;
+  hier_editor_ref editor;
   pkg_description_widget_ref description;
-  vs_table_ref description_table;
+  cw::table_ref description_table;
 
   pkg_why_widget_ref why;
-  vs_table_ref why_table;
+  cw::table_ref why_table;
 
-  vs_text_layout_ref reasons;
-  vs_table_ref reasons_table;
+  cw::text_layout_ref reasons;
+  cw::table_ref reasons_table;
 
   pkgCache::PkgIterator lastPkg;
   pkgCache::VerIterator lastVer;
@@ -285,17 +310,17 @@ class info_area_multiplex:public vs_multiplex
   /** If the view was autoswitched to breakage reasons, this is set
    *  to the widget we switched away from; otherwise, it is \b NULL.
    */
-  vs_widget_ref autoswitch;
+  cw::widget_ref autoswitch;
 
 protected:
-  info_area_multiplex(const vs_hier_editor_ref &_editor,
+  info_area_multiplex(const hier_editor_ref &_editor,
 		      const pkg_description_widget_ref &_description,
-		      const vs_table_ref &_description_table,
+		      const cw::table_ref &_description_table,
 		      const pkg_why_widget_ref &_why,
-		      const vs_table_ref &_why_table,
-		      const vs_text_layout_ref &_reasons,
-		      const vs_table_ref &_reasons_table)
-    :vs_multiplex(false),
+		      const cw::table_ref &_why_table,
+		      const cw::text_layout_ref &_reasons,
+		      const cw::table_ref &_reasons_table)
+    :cw::multiplex(false),
      editor(_editor),
      description(_description), description_table(_description_table),
      why(_why), why_table(_why_table),
@@ -307,16 +332,16 @@ protected:
   }
 
 public:
-  static ref_ptr<info_area_multiplex>
-  create(const vs_hier_editor_ref &editor,
+  static cw::util::ref_ptr<info_area_multiplex>
+  create(const hier_editor_ref &editor,
 	 const pkg_description_widget_ref &description,
-	 const vs_table_ref &description_table,
+	 const cw::table_ref &description_table,
 	 const pkg_why_widget_ref &why,
-	 const vs_table_ref &why_table,
-	 const vs_text_layout_ref &reasons,
-	 const vs_table_ref &reasons_table)
+	 const cw::table_ref &why_table,
+	 const cw::text_layout_ref &reasons,
+	 const cw::table_ref &reasons_table)
   {
-    ref_ptr<info_area_multiplex>
+    cw::util::ref_ptr<info_area_multiplex>
       rval(new info_area_multiplex(editor, description, description_table,
 				   why, why_table, reasons, reasons_table));
     rval->decref();
@@ -325,9 +350,9 @@ public:
 
   void line_up()
   {
-    vs_widget_ref tmpref(this);
+    cw::widget_ref tmpref(this);
 
-    vs_widget_ref w=visible_widget();
+    cw::widget_ref w=visible_widget();
 
     if(w==description_table)
       description->line_up();
@@ -339,9 +364,9 @@ public:
 
   void line_down()
   {
-    vs_widget_ref tmpref(this);
+    cw::widget_ref tmpref(this);
 
-    vs_widget_ref w=visible_widget();
+    cw::widget_ref w=visible_widget();
 
     if(w==description_table)
       description->line_down();
@@ -354,7 +379,7 @@ public:
   void set_package(const pkgCache::PkgIterator &pkg,
 		   const pkgCache::VerIterator &ver)
   {
-    vs_widget_ref tmpref(this);
+    cw::widget_ref tmpref(this);
 
     bool hasBreakage;
 
@@ -400,7 +425,7 @@ public:
   /** Cycles the multiplex, taking autoswitch behavior into account. */
   void cycle()
   {
-    vs_widget_ref tmpref(this);
+    cw::widget_ref tmpref(this);
 
     if(autoswitch.valid() && autoswitch!=visible_widget())
       {
@@ -429,15 +454,15 @@ public:
    */
   void set_description(const std::wstring &s)
   {
-    vs_widget_ref tmpref(this);
+    cw::widget_ref tmpref(this);
 
     if(s!=lastDesc)
       {
 	lastDesc=s;
 
 	description->set_fragment(make_desc_fragment(s));
-	reasons->set_fragment(sequence_fragment(make_desc_fragment(s),
-						newline_fragment(),
+	reasons->set_fragment(cw::sequence_fragment(make_desc_fragment(s),
+						cw::newline_fragment(),
 						nopackage(),
 						NULL));
 
@@ -447,17 +472,17 @@ public:
   }
 };
 
-typedef ref_ptr<info_area_multiplex> info_area_multiplex_ref;
+typedef cw::util::ref_ptr<info_area_multiplex> info_area_multiplex_ref;
 
-vs_widget_ref make_package_view(list<package_view_item> &format,
-				const vs_widget_ref &mainwidget,
+cw::widget_ref make_package_view(list<package_view_item> &format,
+				const cw::widget_ref &mainwidget,
 				menu_redirect *menu_handler,
 				pkg_signal *sig, desc_signal *desc_sig,
 				bool show_reason_first)
 {
   bool found_mainwidget=false;
 
-  vs_table_ref rval=vs_table::create();
+  cw::table_ref rval=cw::table::create();
 
   eassert(mainwidget.valid());
 
@@ -494,37 +519,37 @@ vs_widget_ref make_package_view(list<package_view_item> &format,
 	  break;
 	case PACKAGE_VIEW_DESCRIPTION:
 	  {
-	    vs_hier_editor_ref e=vs_hier_editor::create();
+	    hier_editor_ref e=hier_editor::create();
 	    pkg_description_widget_ref w=pkg_description_widget::create();
 	    pkg_why_widget_ref why = pkg_why_widget::create();
-	    vs_text_layout_ref l=vs_text_layout::create();
+	    cw::text_layout_ref l=cw::text_layout::create();
 
-	    vs_table_ref wt=vs_table::create();
-	    vs_table_ref lt=vs_table::create();
-	    vs_table_ref why_table = vs_table::create();
+	    cw::table_ref wt=cw::table::create();
+	    cw::table_ref lt=cw::table::create();
+	    cw::table_ref why_table = cw::table::create();
 	    info_area_multiplex_ref m=info_area_multiplex::create(e,
 								  w, wt,
 								  why, why_table,
 								  l, lt);
-	    vs_scrollbar_ref ws=vs_scrollbar::create(vs_scrollbar::VERTICAL);
-	    vs_scrollbar_ref ls=vs_scrollbar::create(vs_scrollbar::VERTICAL);
-	    vs_scrollbar_ref why_scrollbar = vs_scrollbar::create(vs_scrollbar::VERTICAL);
+	    cw::scrollbar_ref ws=cw::scrollbar::create(cw::scrollbar::VERTICAL);
+	    cw::scrollbar_ref ls=cw::scrollbar::create(cw::scrollbar::VERTICAL);
+	    cw::scrollbar_ref why_scrollbar = cw::scrollbar::create(cw::scrollbar::VERTICAL);
 
-	    w->location_changed.connect(sigc::mem_fun(*ws.unsafe_get_ref(), &vs_scrollbar::set_slider));
-	    l->location_changed.connect(sigc::mem_fun(*ls.unsafe_get_ref(), &vs_scrollbar::set_slider));
-	    why->location_changed.connect(sigc::mem_fun(*why_scrollbar.unsafe_get_ref(), &vs_scrollbar::set_slider));
+	    w->location_changed.connect(sigc::mem_fun(*ws.unsafe_get_ref(), &cw::scrollbar::set_slider));
+	    l->location_changed.connect(sigc::mem_fun(*ls.unsafe_get_ref(), &cw::scrollbar::set_slider));
+	    why->location_changed.connect(sigc::mem_fun(*why_scrollbar.unsafe_get_ref(), &cw::scrollbar::set_slider));
 
-	    wt->add_widget_opts(w, 0, 0, 1, 1, vs_table::EXPAND | vs_table::FILL | vs_table::SHRINK, vs_table::EXPAND | vs_table::FILL | vs_table::SHRINK);
-	    wt->add_widget_opts(ws, 0, 1, 1, 1, vs_table::ALIGN_RIGHT, vs_table::ALIGN_CENTER | vs_table::FILL);
+	    wt->add_widget_opts(w, 0, 0, 1, 1, cw::table::EXPAND | cw::table::FILL | cw::table::SHRINK, cw::table::EXPAND | cw::table::FILL | cw::table::SHRINK);
+	    wt->add_widget_opts(ws, 0, 1, 1, 1, cw::table::ALIGN_RIGHT, cw::table::ALIGN_CENTER | cw::table::FILL);
 
-	    lt->add_widget_opts(l, 0, 0, 1, 1, vs_table::EXPAND | vs_table::FILL | vs_table::SHRINK, vs_table::EXPAND | vs_table::FILL | vs_table::SHRINK);
-	    lt->add_widget_opts(ls, 0, 1, 1, 1, vs_table::ALIGN_RIGHT, vs_table::EXPAND | vs_table::ALIGN_CENTER | vs_table::FILL);
+	    lt->add_widget_opts(l, 0, 0, 1, 1, cw::table::EXPAND | cw::table::FILL | cw::table::SHRINK, cw::table::EXPAND | cw::table::FILL | cw::table::SHRINK);
+	    lt->add_widget_opts(ls, 0, 1, 1, 1, cw::table::ALIGN_RIGHT, cw::table::EXPAND | cw::table::ALIGN_CENTER | cw::table::FILL);
 
-	    why_table->add_widget_opts(why, 0, 0, 1, 1, vs_table::EXPAND | vs_table::FILL | vs_table::SHRINK, vs_table::EXPAND | vs_table::FILL | vs_table::SHRINK);
-	    why_table->add_widget_opts(why_scrollbar, 0, 1, 1, 1, vs_table::ALIGN_RIGHT, vs_table::EXPAND | vs_table::ALIGN_CENTER | vs_table::FILL);
+	    why_table->add_widget_opts(why, 0, 0, 1, 1, cw::table::EXPAND | cw::table::FILL | cw::table::SHRINK, cw::table::EXPAND | cw::table::FILL | cw::table::SHRINK);
+	    why_table->add_widget_opts(why_scrollbar, 0, 1, 1, 1, cw::table::ALIGN_RIGHT, cw::table::EXPAND | cw::table::ALIGN_CENTER | cw::table::FILL);
 
 	    // HACK: speaks for itself
-	    vs_tree_ref thetree=mainwidget.dyn_downcast<vs_tree>();
+	    cw::tree_ref thetree=mainwidget.dyn_downcast<cw::tree>();
 
 	    i->widget=m;
 
@@ -539,30 +564,30 @@ vs_widget_ref make_package_view(list<package_view_item> &format,
 	    if(desc_sig)
 	      desc_sig->connect(sigc::mem_fun(*m.unsafe_get_ref(), &info_area_multiplex::set_description));
 
-	    mainwidget->connect_key("DescriptionDown", &global_bindings,
+	    mainwidget->connect_key("DescriptionDown", &cw::config::global_bindings,
 				    sigc::mem_fun(*m.unsafe_get_ref(),
 						  &info_area_multiplex::line_down));
-	    mainwidget->connect_key("DescriptionUp", &global_bindings,
+	    mainwidget->connect_key("DescriptionUp", &cw::config::global_bindings,
 				    sigc::mem_fun(*m.unsafe_get_ref(),
 						  &info_area_multiplex::line_up));
-	    mainwidget->connect_key("DescriptionCycle", &global_bindings,
+	    mainwidget->connect_key("DescriptionCycle", &cw::config::global_bindings,
 				    sigc::mem_fun(*m.unsafe_get_ref(),
 						  &info_area_multiplex::cycle));
-	    mainwidget->connect_key("EditHier", &global_bindings,
+	    mainwidget->connect_key("EditHier", &cw::config::global_bindings,
 				    sigc::mem_fun(*e.unsafe_get_ref(),
-						  &vscreen_widget::show));
-	    mainwidget->connect_key("EditHier", &global_bindings,
+						  &cw::widget::show));
+	    mainwidget->connect_key("EditHier", &cw::config::global_bindings,
 				    sigc::mem_fun(*m.unsafe_get_ref(),
-						  &vscreen_widget::show));
-	    mainwidget->connect_key("EditHier", &global_bindings,
-				    sigc::bind(sigc::mem_fun(*rval.unsafe_get_ref(), &vs_table::focus_widget_bare),
+						  &cw::widget::show));
+	    mainwidget->connect_key("EditHier", &cw::config::global_bindings,
+				    sigc::bind(sigc::mem_fun(*rval.unsafe_get_ref(), &cw::table::focus_widget_bare),
 					       m.weak_ref()));
 
-	    e->hidden_sig.connect(sigc::bind(sigc::mem_fun(*rval.unsafe_get_ref(), &vs_table::focus_widget_bare),
+	    e->hidden_sig.connect(sigc::bind(sigc::mem_fun(*rval.unsafe_get_ref(), &cw::table::focus_widget_bare),
 					     mainwidget.weak_ref()));
 
 	    if(thetree.valid())
-	      e->commit_changes.connect(sigc::mem_fun(*thetree.unsafe_get_ref(), &vs_tree::line_down));
+	      e->commit_changes.connect(sigc::mem_fun(*thetree.unsafe_get_ref(), &cw::tree::line_down));
 
 	    m->add_visible_widget(e, false);
 	    m->add_visible_widget(wt, true);
@@ -593,8 +618,8 @@ vs_widget_ref make_package_view(list<package_view_item> &format,
 	  if(i->type == PACKAGE_VIEW_MAINWIDGET ||
 	     i->type == PACKAGE_VIEW_DESCRIPTION)
 	    {
-	      xopts|=vs_table::IGNORE_SIZE_REQUEST;
-	      yopts|=vs_table::IGNORE_SIZE_REQUEST;
+	      xopts|=cw::table::IGNORE_SIZE_REQUEST;
+	      yopts|=cw::table::IGNORE_SIZE_REQUEST;
 	    }
 
 	  rval->add_widget_opts(i->widget, i->row, i->col, i->h, i->w,
@@ -604,9 +629,9 @@ vs_widget_ref make_package_view(list<package_view_item> &format,
 
 	  if(i->popupdownkey.size()>0)
 	    rval->connect_key(i->popupdownkey,
-			      &global_bindings,
+			      &cw::config::global_bindings,
 			      sigc::mem_fun(*i->widget.unsafe_get_ref(),
-					    &vscreen_widget::toggle_visible));
+					    &cw::widget::toggle_visible));
 
 	  if(i->visible)
 	    i->widget->show();
@@ -625,8 +650,8 @@ vs_widget_ref make_package_view(list<package_view_item> &format,
 	  if(!strcasecmp(j->name.c_str(), i->popupdownlinked.c_str()))
 	    {
 	      // Having to make two connections is annoying.
-	      j->widget->shown_sig.connect(sigc::mem_fun(*i->widget.unsafe_get_ref(), &vscreen_widget::show));
-	      j->widget->hidden_sig.connect(sigc::mem_fun(*i->widget.unsafe_get_ref(), &vscreen_widget::hide));
+	      j->widget->shown_sig.connect(sigc::mem_fun(*i->widget.unsafe_get_ref(), &cw::widget::show));
+	      j->widget->hidden_sig.connect(sigc::mem_fun(*i->widget.unsafe_get_ref(), &cw::widget::hide));
 	      break;
 	    }
 	}
