@@ -11,9 +11,12 @@
 
 #include <generic/apt/infer_reason.h>
 
-class fragment;
+namespace cwidget
+{
+  class fragment;
+}
 
-/** Generate a fragment containing a (multi-line) description of why
+/** Generate a cwidget::fragment containing a (multi-line) description of why
  *  the package is in its present state.
  *
  *  If pkg.end() is \b true, returns nopackage().
@@ -26,10 +29,10 @@ class fragment;
  *                 one of its reverse dependencies.
  *  \return the new text fragment
  */
-fragment *reason_fragment(const pkgCache::PkgIterator &pkg,
-			  bool &breakage);
+cwidget::fragment *reason_fragment(const pkgCache::PkgIterator &pkg,
+				   bool &breakage);
 
-/** Generate a fragment containing a (multi-line) description of why
+/** Generate a cwidget::fragment containing a (multi-line) description of why
  *  the package is in its present state.
  *
  *  If pkg.end() is \b true, returns nopackage().
@@ -37,9 +40,9 @@ fragment *reason_fragment(const pkgCache::PkgIterator &pkg,
  *  \param pkg the package to examine
  *  \return the new text fragment
  */
-fragment *reason_fragment(const pkgCache::PkgIterator &pkg);
+cwidget::fragment *reason_fragment(const pkgCache::PkgIterator &pkg);
 
 /** \return a string explaining that no package is selected. */
-fragment *nopackage();
+cwidget::fragment *nopackage();
 
 #endif
