@@ -34,19 +34,25 @@
 
 #include <sigc++/adaptors/bind.h>
 
-#include <vscreen/config/style.h>
-#include <vscreen/fragment.h>
-#include <vscreen/transcode.h>
-#include <vscreen/vs_label.h>
-#include <vscreen/vs_layout_item.h>
-#include <vscreen/vs_multiplex.h>
-#include <vscreen/vs_staticitem.h>
-#include <vscreen/vs_subtree.h>
-#include <vscreen/vs_table.h>
+#include <cwidget/fragment.h>
+#include <cwidget/generic/util/transcode.h>
+#include <cwidget/style.h>
+#include <cwidget/toplevel.h>
+#include <cwidget/widgets/label.h>
+#include <cwidget/widgets/layout_item.h>
+#include <cwidget/widgets/multiplex.h>
+#include <cwidget/widgets/staticitem.h>
+#include <cwidget/widgets/subtree.h>
+#include <cwidget/widgets/table.h>
 
 typedef generic_solution<aptitude_universe> aptitude_solution;
 
 using namespace std;
+namespace cw = cwidget;
+namespace cwidget
+{
+  using namespace widgets;
+}
 
 struct act_name_lt
 {
@@ -104,23 +110,23 @@ void bin_actions(const aptitude_solution &sol,
       }
 }
 
-class label_tree : public vs_subtree_generic
+class label_tree : public cw::subtree_generic
 {
   wstring my_label;
 public:
   label_tree(wstring _label, bool _expanded = true,
 	     bool selectable = true,
 	     int depth = 0)
-    :vs_subtree_generic(_expanded), my_label(_label)
+    :cw::subtree_generic(_expanded), my_label(_label)
   {
     set_selectable(selectable);
     set_depth(depth);
   }
 
-  void paint(vs_tree *win, int y, bool hierarchical,
-	     const style &st)
+  void paint(cw::tree *win, int y, bool hierarchical,
+	     const cw::style &st)
   {
-    vs_subtree<vs_treeitem>::paint(win, y, hierarchical, my_label);
+    cw::subtree<cw::treeitem>::paint(win, y, hierarchical, my_label);
   }
 
   const wchar_t *tag()
@@ -136,17 +142,17 @@ public:
 
 
 
-vs_subtree_generic *make_dep_solvers_tree(const aptitude_resolver_dep &d)
+cw::subtree_generic *make_dep_solvers_tree(const aptitude_resolver_dep &d)
 {
   pkgCache::DepIterator real_dep = d.get_dep();
   pkgCache::PrvIterator prv = d.get_prv();
 
-  vs_subtree_generic *root = new label_tree(L"", true, true, -1);
+  cw::subtree_generic *root = new label_tree(L"", true, true, -1);
 
-  vs_staticitem *conflict_item = new vs_staticitem(conflict_text(real_dep, prv), L"");
+  cw::staticitem *conflict_item = new cw::staticitem(conflict_text(real_dep, prv), L"");
   root->add_child(conflict_item);
 
-  vs_subtree_generic *resolvers = new label_tree(transcode(_("The following actions will resolve this dependency:")), true, false);
+  cw::subtree_generic *resolvers = new label_tree(W_("The following actions will resolve this dependency:"), true, false);
 
   root->add_child(resolvers);
 
@@ -157,7 +163,7 @@ vs_subtree_generic *make_dep_solvers_tree(const aptitude_resolver_dep &d)
 	aptitude_solution::action act(*vi, d, true, 0);
 
 	resolvers->add_child(new solution_act_item(act,
-						   sigc::slot1<void, fragment *>(),
+						   sigc::slot1<void, cw::fragment *>(),
 						   sigc::slot1<void, aptitude_resolver_dep>()));
       }
 
@@ -167,7 +173,7 @@ vs_subtree_generic *make_dep_solvers_tree(const aptitude_resolver_dep &d)
       aptitude_solution::action act(*si, d, false, 0);
 
       resolvers->add_child(new solution_act_item(act,
-						 sigc::slot1<void, fragment *>(),
+						 sigc::slot1<void, cw::fragment *>(),
 						 sigc::slot1<void, aptitude_resolver_dep>()));
     }
 
@@ -177,8 +183,8 @@ vs_subtree_generic *make_dep_solvers_tree(const aptitude_resolver_dep &d)
   return root;
 }
 
-vs_subtree_generic *make_story_tree(const aptitude_solution &sol,
-				    const sigc::slot1<void, fragment *> &set_short_description,
+cw::subtree_generic *make_story_tree(const aptitude_solution &sol,
+				    const sigc::slot1<void, cw::fragment *> &set_short_description,
 				    const sigc::slot1<void, aptitude_resolver_dep> &set_active_dep)
 {
   vector<aptitude_solution::action> actions;
@@ -189,12 +195,12 @@ vs_subtree_generic *make_story_tree(const aptitude_solution &sol,
 
   sort(actions.begin(), actions.end(), aptitude_solution::action_id_compare());
 
-  vs_subtree_generic *root = new label_tree(L"");
+  cw::subtree_generic *root = new label_tree(L"");
 
   for(vector<aptitude_solution::action>::const_iterator
 	i = actions.begin(); i != actions.end(); ++i)
     {
-      vs_subtree_generic *tree = new label_tree(dep_text(i->d.get_dep()), true, false);
+      cw::subtree_generic *tree = new label_tree(dep_text(i->d.get_dep()), true, false);
 
       tree->add_child(new solution_act_item(*i, set_short_description, set_active_dep));
       root->add_child(tree);
@@ -203,8 +209,8 @@ vs_subtree_generic *make_story_tree(const aptitude_solution &sol,
   return root;
 }
 
-vs_subtree_generic *make_solution_tree(const aptitude_solution &sol,
-				       const sigc::slot1<void, fragment *> &set_short_description,
+cw::subtree_generic *make_solution_tree(const aptitude_solution &sol,
+				       const sigc::slot1<void, cw::fragment *> &set_short_description,
 				       const sigc::slot1<void, aptitude_resolver_dep> &set_active_dep)
 {
   // Bin packages according to what will happen to them.
@@ -228,11 +234,11 @@ vs_subtree_generic *make_solution_tree(const aptitude_solution &sol,
   sort(upgrade_actions.begin(), upgrade_actions.end(),
        act_name_lt());
 
-  vs_subtree_generic *root = new label_tree(L"");
+  cw::subtree_generic *root = new label_tree(L"");
 
   if(!remove_actions.empty())
     {
-      vs_subtree_generic *remove_tree = new label_tree(transcode(_("Remove the following packages:")));
+      cw::subtree_generic *remove_tree = new label_tree(W_("Remove the following packages:"));
 
       for(vector<aptitude_solution::action>::const_iterator i = remove_actions.begin();
 	  i != remove_actions.end(); ++i)
@@ -243,7 +249,7 @@ vs_subtree_generic *make_solution_tree(const aptitude_solution &sol,
 
   if(!keep_actions.empty())
     {
-      vs_subtree_generic *keep_tree = new label_tree(transcode(_("Keep the following packages at their current version:")));
+      cw::subtree_generic *keep_tree = new label_tree(W_("Keep the following packages at their current version:"));
 
       for(vector<aptitude_solution::action>::const_iterator i = keep_actions.begin();
 	  i != keep_actions.end(); ++i)
@@ -254,7 +260,7 @@ vs_subtree_generic *make_solution_tree(const aptitude_solution &sol,
 
   if(!install_actions.empty())
     {
-      vs_subtree_generic *install_tree = new label_tree(transcode(_("Install the following packages:")));
+      cw::subtree_generic *install_tree = new label_tree(W_("Install the following packages:"));
 
       for(vector<aptitude_solution::action>::const_iterator i = install_actions.begin();
 	  i != install_actions.end(); ++i)
@@ -265,7 +271,7 @@ vs_subtree_generic *make_solution_tree(const aptitude_solution &sol,
 
   if(!upgrade_actions.empty())
     {
-      vs_subtree_generic *upgrade_tree = new label_tree(transcode(_("Upgrade the following packages:")));
+      cw::subtree_generic *upgrade_tree = new label_tree(W_("Upgrade the following packages:"));
 
       for(vector<aptitude_solution::action>::const_iterator i = upgrade_actions.begin();
 	  i != upgrade_actions.end(); ++i)
@@ -276,7 +282,7 @@ vs_subtree_generic *make_solution_tree(const aptitude_solution &sol,
 
   if(!downgrade_actions.empty())
     {
-      vs_subtree_generic *downgrade_tree = new label_tree(transcode(_("Downgrade the following packages:")));
+      cw::subtree_generic *downgrade_tree = new label_tree(W_("Downgrade the following packages:"));
 
       for(vector<aptitude_solution::action>::const_iterator i = downgrade_actions.begin();
 	  i != downgrade_actions.end(); ++i)
@@ -289,7 +295,7 @@ vs_subtree_generic *make_solution_tree(const aptitude_solution &sol,
 
   if(!unresolved.empty())
     {
-      vs_subtree_generic *unresolved_tree = new label_tree(transcode(_("Leave the following recommendations unresolved:")));
+      cw::subtree_generic *unresolved_tree = new label_tree(W_("Leave the following recommendations unresolved:"));
 
       for(imm::set<aptitude_universe::dep>::const_iterator i = unresolved.begin();
 	  i != unresolved.end(); ++i)
@@ -311,9 +317,9 @@ protected:
   {
   }
 public:
-  static ref_ptr<solution_undo_tree> create()
+  static cw::util::ref_ptr<solution_undo_tree> create()
   {
-    ref_ptr<solution_undo_tree> rval(new solution_undo_tree);
+    cw::util::ref_ptr<solution_undo_tree> rval(new solution_undo_tree);
     rval->decref();
     return rval;
   }
@@ -328,16 +334,16 @@ public:
     return resman != NULL && resman->undo();
   }
 };
-typedef ref_ptr<solution_undo_tree> solution_undo_tree_ref;
+typedef cw::util::ref_ptr<solution_undo_tree> solution_undo_tree_ref;
 
-class solution_examiner : public vs_multiplex
+class solution_examiner : public cw::multiplex
 {
   aptitude_solution last_sol;
 
   menu_tree_ref solution_tree;
   menu_tree_ref story_tree;
 
-  sigc::slot1<void, fragment *> set_short_description;
+  sigc::slot1<void, cw::fragment *> set_short_description;
   sigc::slot1<void, aptitude_resolver_dep> set_active_dep;
 
   void attach_apt_cache_signals()
@@ -356,8 +362,8 @@ class solution_examiner : public vs_multiplex
 
   void set_static_root(const wstring &s)
   {
-    solution_tree->set_root(new vs_layout_item(hardwrapbox(text_fragment(s))), true);
-    story_tree->set_root(new vs_layout_item(hardwrapbox(text_fragment(s))), true);
+    solution_tree->set_root(new cw::layout_item(cw::hardwrapbox(cw::text_fragment(s))), true);
+    story_tree->set_root(new cw::layout_item(cw::hardwrapbox(cw::text_fragment(s))), true);
   }
 
   /** Send highlighted/unhighlighted messages to the subwidgets so
@@ -365,7 +371,7 @@ class solution_examiner : public vs_multiplex
    */
   void update_highlights()
   {
-    vs_widget_ref tmpref(this);
+    cw::widget_ref tmpref(this);
 
     if(solution_tree == visible_widget())
       {
@@ -381,7 +387,7 @@ class solution_examiner : public vs_multiplex
 
   void tick()
   {
-    vs_widget_ref tmpref(this);
+    cw::widget_ref tmpref(this);
 
     if(resman != NULL && resman->resolver_exists())
       {
@@ -392,13 +398,13 @@ class solution_examiner : public vs_multiplex
 	  update_from_state(state);
       }
 
-    vscreen_addtimeout(new slot_event(sigc::mem_fun(this, &solution_examiner::tick)), 1000);
+    cw::toplevel::addtimeout(new cw::toplevel::slot_event(sigc::mem_fun(this, &solution_examiner::tick)), 1000);
   }
 
 protected:
-  solution_examiner(const sigc::slot1<void, fragment *> &_set_short_description,
+  solution_examiner(const sigc::slot1<void, cw::fragment *> &_set_short_description,
 		    const sigc::slot1<void, aptitude_resolver_dep> &_set_active_dep)
-    : vs_multiplex(false),
+    : cw::multiplex(false),
       solution_tree(solution_undo_tree::create()), story_tree(solution_undo_tree::create()),
       set_short_description(_set_short_description),
       set_active_dep(_set_active_dep)
@@ -414,21 +420,21 @@ protected:
 
     cycled.connect(sigc::mem_fun(*this, &solution_examiner::update_highlights));
 
-    vscreen_addtimeout(new slot_event(sigc::mem_fun(this, &solution_examiner::tick)), 1000);
+    cw::toplevel::addtimeout(new cw::toplevel::slot_event(sigc::mem_fun(this, &solution_examiner::tick)), 1000);
 
     // Because the update event might destroy this object, it needs to
     // take place after the constructor returns.
-    vscreen_post_event(new slot_event(sigc::mem_fun(this, &solution_examiner::update)));
+    cw::toplevel::post_event(new cw::toplevel::slot_event(sigc::mem_fun(this, &solution_examiner::update)));
   }
 
-  bool handle_key(const key &k)
+  bool handle_key(const cw::config::key &k)
   {
-    vs_widget_ref tmpref(this);
+    cw::widget_ref tmpref(this);
 
-    if(global_bindings.key_matches(k, "CycleOrder"))
+    if(cw::config::global_bindings.key_matches(k, "CycleOrder"))
       cycle_forward();
     else
-      return vs_multiplex::handle_key(k);
+      return cw::multiplex::handle_key(k);
 
     return true;
   }
@@ -439,38 +445,38 @@ public:
     create_menu_bindings(solution_tree.unsafe_get_ref(), solution_tree);
   }
 
-  static ref_ptr<solution_examiner> create(const sigc::slot1<void, fragment *> &set_short_description,
+  static cw::util::ref_ptr<solution_examiner> create(const sigc::slot1<void, cw::fragment *> &set_short_description,
 					   const sigc::slot1<void, aptitude_resolver_dep> &set_active_dep)
   {
-    ref_ptr<solution_examiner>
+    cw::util::ref_ptr<solution_examiner>
       rval(new solution_examiner(set_short_description, set_active_dep));
     rval->decref();
     return rval;
   }
 
-  void paint(const style &st)
+  void paint(const cw::style &st)
   {
     if(apt_cache_file == NULL)
       update();
 
-    vs_multiplex::paint(st);
+    cw::multiplex::paint(st);
   }
 
   void update()
   {
-    ref_ptr<solution_examiner> tmpref(this);
+    cw::util::ref_ptr<solution_examiner> tmpref(this);
 
     if(!apt_cache_file)
       {
-	set_static_root(transcode(_("The package cache is not available.")));
+	set_static_root(W_("The package cache is not available."));
 	set_active_dep(aptitude_resolver_dep());
 	return;
       }
 
     if(!resman->resolver_exists())
       {
-	set_static_root(transcode(_("No broken packages.")));
-	set_short_description(fragf(""));
+	set_static_root(W_("No broken packages."));
+	set_short_description(cw::fragf(""));
 	set_active_dep(aptitude_resolver_dep());
 	return;
       }
@@ -481,11 +487,11 @@ public:
 
   void update_from_state(const resolver_manager::state &state)
   {
-    vs_widget_ref tmpref(this);
+    cw::widget_ref tmpref(this);
 
     if(state.solutions_exhausted && state.generated_solutions == 0)
       {
-	set_static_root(transcode(_("No resolution found.")));
+	set_static_root(W_("No resolution found."));
 	last_sol.nullify();
 	return;
       }
@@ -494,22 +500,22 @@ public:
       {
 	if(state.background_thread_aborted)
 	  {
-	    set_static_root(transcode(state.background_thread_abort_msg));
+	    set_static_root(cw::util::transcode(state.background_thread_abort_msg));
 	    last_sol.nullify();
 	    return;
 	  }
 
-	wstring generation_info = swsprintf(transcode(_("open: %d; closed: %d; defer: %d; conflict: %d")).c_str(),
+	wstring generation_info = swsprintf(W_("open: %d; closed: %d; defer: %d; conflict: %d").c_str(),
 					    state.open_size, state.closed_size,
 					    state.deferred_size, state.conflicts_size);
 
-	wstring msg = transcode(_("Resolving dependencies..."));
+	wstring msg = W_("Resolving dependencies...");
 
-	vs_subtree_generic *sol_root = new label_tree(msg);
-	sol_root->add_child(new vs_layout_item(hardwrapbox(text_fragment(generation_info))));
+	cw::subtree_generic *sol_root = new label_tree(msg);
+	sol_root->add_child(new cw::layout_item(cw::hardwrapbox(cw::text_fragment(generation_info))));
 
-	vs_subtree_generic *story_root = new label_tree(msg);
-	story_root->add_child(new vs_layout_item(hardwrapbox(text_fragment(generation_info))));
+	cw::subtree_generic *story_root = new label_tree(msg);
+	story_root->add_child(new cw::layout_item(cw::hardwrapbox(cw::text_fragment(generation_info))));
 
 	solution_tree->set_root(sol_root, true);
 	story_tree->set_root(story_root, true);
@@ -526,7 +532,7 @@ public:
     last_sol = sol;
 
     if(sol.get_actions().empty())
-      set_static_root(transcode(_("Internal error: unexpected null solution.")));
+      set_static_root(W_("Internal error: unexpected null solution."));
     else
       {
 	solution_tree->set_root(make_solution_tree(sol, set_short_description, set_active_dep));
@@ -537,12 +543,12 @@ public:
   }
 };
 
-typedef ref_ptr<solution_examiner> solution_examiner_ref;
+typedef cw::util::ref_ptr<solution_examiner> solution_examiner_ref;
 
 static
-void update_dep_display(aptitude_resolver_dep d, vs_tree *tBare)
+void update_dep_display(aptitude_resolver_dep d, cw::tree *tBare)
 {
-  vs_tree_ref t(tBare);
+  cw::tree_ref t(tBare);
 
   if(d.get_dep().end())
     t->set_root(NULL);
@@ -551,24 +557,24 @@ void update_dep_display(aptitude_resolver_dep d, vs_tree *tBare)
 }
 
 static
-void maybe_remove_examiner(vscreen_widget &wBare)
+void maybe_remove_examiner(cw::widget &wBare)
 {
-  vs_widget_ref w(&wBare);
+  cw::widget_ref w(&wBare);
 
   if(resman && !resman->resolver_exists())
     w->destroy();
 }
 
-vs_widget_ref make_solution_screen()
+cw::widget_ref make_solution_screen()
 {
-  vs_table_ref rval     = vs_table::create();
+  cw::table_ref rval     = cw::table::create();
 
-  vs_label_ref l        = vs_label::create(L"");
+  cw::label_ref l        = cw::label::create(L"");
   menu_tree_ref info_tree = solution_undo_tree::create();
 
   solution_examiner_ref examiner
     = solution_examiner::create(sigc::mem_fun(l.unsafe_get_ref(),
-					      (void (vs_label::*) (fragment *)) &vs_label::set_text),
+					      (void (cw::label::*) (cw::fragment *)) &cw::label::set_text),
 				sigc::bind(sigc::ptr_fun(update_dep_display),
 					   info_tree.unsafe_get_ref()));
 
@@ -577,22 +583,22 @@ vs_widget_ref make_solution_screen()
   create_menu_bindings(info_tree.unsafe_get_ref(), info_tree);
 
 
-  info_tree->connect_key("ShowHideDescription", &global_bindings,
+  info_tree->connect_key("ShowHideDescription", &cw::config::global_bindings,
 			 sigc::mem_fun(info_tree.unsafe_get_ref(),
-				       &vscreen_widget::toggle_visible));
+				       &cw::widget::toggle_visible));
 
-  l->set_bg_style(get_style("Status"));
+  l->set_bg_style(cw::get_style("Status"));
 
   rval->add_widget_opts(examiner,
-			0, 0, 1, 1, vs_table::EXPAND | vs_table::FILL,
-			vs_table::EXPAND | vs_table::FILL | vs_table::SHRINK);
+			0, 0, 1, 1, cw::table::EXPAND | cw::table::FILL,
+			cw::table::EXPAND | cw::table::FILL | cw::table::SHRINK);
   rval->add_widget_opts(l,
-			1, 0, 1, 1, vs_table::EXPAND | vs_table::FILL,
+			1, 0, 1, 1, cw::table::EXPAND | cw::table::FILL,
 			0);
 
   rval->add_widget_opts(info_tree,
-			2, 0, 1, 1, vs_table::EXPAND | vs_table::FILL,
-			vs_table::EXPAND | vs_table::FILL | vs_table::SHRINK);
+			2, 0, 1, 1, cw::table::EXPAND | cw::table::FILL,
+			cw::table::EXPAND | cw::table::FILL | cw::table::SHRINK);
 
 
   cache_reloaded.connect(sigc::bind(sigc::ptr_fun(&maybe_remove_examiner),
