@@ -20,18 +20,24 @@
 #ifndef SOLUTION_SCREEN_H
 #define SOLUTION_SCREEN_H
 
-#include <vscreen/ref_ptr.h>
+#include <cwidget/generic/util/ref_ptr.h>
 
 class aptitude_universe;
 template<class PackageUniverse> class generic_solution;
-class vscreen_widget;
+namespace cwidget
+{
+  namespace widgets
+  {
+    class widget;
+    typedef util::ref_ptr<cwidget::widgets::widget> widget_ref;
+  }
+}
 
 typedef generic_solution<aptitude_universe> aptitude_solution;
-typedef ref_ptr<vscreen_widget> vs_widget_ref;
 
 /** Generate a new widget suitable for inclusion at the top-level
  *  which describes the given solution.
  */
-vs_widget_ref make_solution_screen();
+cwidget::widgets::widget_ref make_solution_screen();
 
 #endif // SOLUTION_SCREEN_H
