@@ -21,7 +21,7 @@
 
 #include "aptitude.h"
 #include "ui.h"
-#include "vs_progress.h"
+#include "progress.h"
 
 #include <generic/apt/apt.h>
 #include <generic/apt/download_manager.h>
@@ -29,7 +29,13 @@
 
 #include <sigc++/functors/mem_fun.h>
 
-#include <vscreen/vscreen_widget.h> // For vs_widget_ref
+#include <cwidget/widgets/widget.h> // For cw::widget_ref
+
+namespace cw = cwidget;
+namespace cwidget
+{
+  using namespace widgets;
+}
 
 ui_download_manager::ui_download_manager(download_manager *_manager,
 					 bool force_noninvasive,
@@ -41,11 +47,11 @@ ui_download_manager::ui_download_manager(download_manager *_manager,
   : manager(_manager),
     t(NULL)
 {
-  std::pair<download_signal_log *, vs_widget_ref> progpair =
+  std::pair<download_signal_log *, cw::widget_ref> progpair =
     gen_download_progress(force_noninvasive, list_update,
 			  title, longtitle, tablabel,
-			  arg(sigc::mem_fun(abort_state,
-					    &aborter::abort)));
+			  cw::util::arg(sigc::mem_fun(abort_state,
+						      &aborter::abort)));
 
   log             = progpair.first;
   download_status = progpair.second;
@@ -71,7 +77,7 @@ ui_download_manager::~ui_download_manager()
 
 void ui_download_manager::done(download_thread *, pkgAcquire::RunResult res)
 {
-  vs_progress_ref p = gen_progress_bar();
+  progress_ref p = gen_progress_bar();
 
   download_manager::result run_res = download_manager::failure;
 
@@ -95,7 +101,7 @@ void ui_download_manager::done(download_thread *, pkgAcquire::RunResult res)
 
 void ui_download_manager::start()
 {
-  vs_progress_ref p = gen_progress_bar();
+  progress_ref p = gen_progress_bar();
 
   bool ok = manager->prepare(*p.unsafe_get_ref(), *st, log);
 
