@@ -17,13 +17,13 @@
 //   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 //   Boston, MA 02111-1307, USA.
 
-#include <vscreen/config/colors.h>
-#include <vscreen/config/keybindings.h>
-#include <vscreen/transcode.h>
-#include <vscreen/vs_pager.h>
-#include <vscreen/vs_scrollbar.h>
-#include <vscreen/vs_table.h>
-#include <vscreen/vs_text_layout.h>
+#include <cwidget/config/colors.h>
+#include <cwidget/config/keybindings.h>
+#include <cwidget/generic/util/transcode.h>
+#include <cwidget/widgets/pager.h>
+#include <cwidget/widgets/scrollbar.h>
+#include <cwidget/widgets/table.h>
+#include <cwidget/widgets/text_layout.h>
 
 #include "changelog_parse.h"
 #include "download_bar.h"
@@ -44,7 +44,13 @@
 
 using namespace std;
 
-class pkg_changelog_screen : public vs_file_pager, public menu_redirect
+namespace cw = cwidget;
+namespace cwidget
+{
+  using namespace widgets;
+}
+
+class pkg_changelog_screen : public cw::file_pager, public menu_redirect
 {
   bool last_search_forwards;
 
@@ -52,9 +58,9 @@ class pkg_changelog_screen : public vs_file_pager, public menu_redirect
   {
     last_search_forwards = true;
 
-    prompt_string(transcode(_("Search for: ")),
+    prompt_string(W_("Search for: "),
 		  get_last_search(),
-		  arg(sigc::mem_fun(*this, &vs_pager::search_for)),
+		  cw::util::arg(sigc::mem_fun(*this, &cw::pager::search_for)),
 		  NULL,
 		  NULL,
 		  NULL);
@@ -64,9 +70,9 @@ class pkg_changelog_screen : public vs_file_pager, public menu_redirect
   {
     last_search_forwards = false;
 
-    prompt_string(transcode(_("Search backwards for: ")),
+    prompt_string(W_("Search backwards for: "),
 		  get_last_search(),
-		  arg(sigc::mem_fun(*this, &vs_pager::search_back_for)),
+		  cw::util::arg(sigc::mem_fun(*this, &cw::pager::search_back_for)),
 		  NULL,
 		  NULL,
 		  NULL);
@@ -92,24 +98,24 @@ protected:
   pkg_changelog_screen(const temp::name &filename,
 		       int x = 0, int y = 0,
 		       int width = 0, int height = 0):
-    vs_file_pager(filename.get_name()), last_search_forwards(true)
+    cw::file_pager(filename.get_name()), last_search_forwards(true)
   {
-    connect_key("Search", &global_bindings,
+    connect_key("Search", &cw::config::global_bindings,
 		sigc::mem_fun(*this, &pkg_changelog_screen::do_search));
-    connect_key("SearchBack", &global_bindings,
+    connect_key("SearchBack", &cw::config::global_bindings,
 		sigc::mem_fun(*this, &pkg_changelog_screen::do_search_back));
-    connect_key("ReSearch", &global_bindings,
+    connect_key("ReSearch", &cw::config::global_bindings,
 		sigc::mem_fun(*this, &pkg_changelog_screen::do_repeat_search));
-    connect_key("RepeatSearchBack", &global_bindings,
+    connect_key("RepeatSearchBack", &cw::config::global_bindings,
 		sigc::mem_fun(*this, &pkg_changelog_screen::do_repeat_search_back));
   }
 
 public:
-  static ref_ptr<pkg_changelog_screen>
+  static cw::util::ref_ptr<pkg_changelog_screen>
   create(const temp::name &filename,
 	 int x = 0, int y = 0, int width = 0, int height = 0)
   {
-    ref_ptr<pkg_changelog_screen>
+    cw::util::ref_ptr<pkg_changelog_screen>
       rval(new pkg_changelog_screen(filename, x, y, width, height));
     rval->decref();
     return rval;
@@ -148,7 +154,7 @@ public:
     return true;
   }
 };
-typedef ref_ptr<pkg_changelog_screen> pkg_changelog_screen_ref;
+typedef cw::util::ref_ptr<pkg_changelog_screen> pkg_changelog_screen_ref;
 
 
 static void do_view_changelog(temp::name n,
@@ -160,39 +166,39 @@ static void do_view_changelog(temp::name n,
   string tablabel = ssprintf(_("%s changes"), pkgname.c_str());
   string desclabel = _("View the list of changes made to this Debian package.");
 
-  fragment *f = make_changelog_fragment(n, curverstr);
+  cw::fragment *f = make_changelog_fragment(n, curverstr);
 
-  vs_table_ref           t = vs_table::create();
+  cw::table_ref           t = cw::table::create();
   if(f != NULL)
     {
-      vs_scrollbar_ref   s = vs_scrollbar::create(vs_scrollbar::VERTICAL);
+      cw::scrollbar_ref   s = cw::scrollbar::create(cw::scrollbar::VERTICAL);
       menu_text_layout_ref l = menu_text_layout::create();
 
 
-      l->location_changed.connect(sigc::mem_fun(s.unsafe_get_ref(), &vs_scrollbar::set_slider));
-      s->scrollbar_interaction.connect(sigc::mem_fun(l.unsafe_get_ref(), &vs_text_layout::scroll));
+      l->location_changed.connect(sigc::mem_fun(s.unsafe_get_ref(), &cw::scrollbar::set_slider));
+      s->scrollbar_interaction.connect(sigc::mem_fun(l.unsafe_get_ref(), &cw::text_layout::scroll));
       l->set_fragment(f);
 
       t->add_widget_opts(l, 0, 0, 1, 1,
-			 vs_table::EXPAND|vs_table::SHRINK, vs_table::EXPAND);
+			 cw::table::EXPAND|cw::table::SHRINK, cw::table::EXPAND);
       t->add_widget_opts(s, 0, 1, 1, 1, 0,
-			 vs_table::EXPAND | vs_table::FILL);
+			 cw::table::EXPAND | cw::table::FILL);
 
       create_menu_bindings(l.unsafe_get_ref(), t);
     }
   else
     {
       pkg_changelog_screen_ref cs = pkg_changelog_screen::create(n);
-      vs_scrollbar_ref          s = vs_scrollbar::create(vs_scrollbar::VERTICAL);
+      cw::scrollbar_ref          s = cw::scrollbar::create(cw::scrollbar::VERTICAL);
 
-      cs->line_changed.connect(sigc::mem_fun(s.unsafe_get_ref(), &vs_scrollbar::set_slider));
+      cs->line_changed.connect(sigc::mem_fun(s.unsafe_get_ref(), &cw::scrollbar::set_slider));
       s->scrollbar_interaction.connect(sigc::mem_fun(cs.unsafe_get_ref(), &pkg_changelog_screen::scroll_page));
       cs->scroll_top();
 
       t->add_widget_opts(cs, 0, 0, 1, 1,
-			 vs_table::EXPAND|vs_table::SHRINK, vs_table::EXPAND);
+			 cw::table::EXPAND|cw::table::SHRINK, cw::table::EXPAND);
       t->add_widget_opts(s, 0, 1, 1, 1, 0,
-			 vs_table::EXPAND | vs_table::FILL);
+			 cw::table::EXPAND | cw::table::FILL);
 
       create_menu_bindings(cs.unsafe_get_ref(), t);
     }
@@ -223,7 +229,7 @@ void view_changelog(pkgCache::VerIterator ver)
   if(!in_debian)
     {
       show_message(_("You can only view changelogs of official Debian packages."),
-		   NULL, get_style("Error"));
+		   NULL, cw::get_style("Error"));
       return;
     }
 
